class DataGridViewTopLeftHeaderCell(DataGridViewColumnHeaderCell,ICloneable,IDisposable):
 """
 Represents the cell in the top left corner of the System.Windows.Forms.DataGridView that sits above the row headers and to the left of the column headers.

 

 DataGridViewTopLeftHeaderCell()
 """
 def BorderWidths(self,*args):
  """
  BorderWidths(self: DataGridViewCell,advancedBorderStyle: DataGridViewAdvancedBorderStyle) -> Rectangle

  

   Returns a System.Drawing.Rectangle that represents the widths of all the cell margins.

  

   advancedBorderStyle: A System.Windows.Forms.DataGridViewAdvancedBorderStyle that the margins are to be calculated for.

   Returns: A System.Drawing.Rectangle that represents the widths of all the cell margins.
  """
  pass
 def ClickUnsharesRow(self,*args):
  """
  ClickUnsharesRow(self: DataGridViewCell,e: DataGridViewCellEventArgs) -> bool

  

   Indicates whether the cell's row will be unshared when the cell is clicked.

  

   e: The System.Windows.Forms.DataGridViewCellEventArgs containing the data passed to the 

    System.Windows.Forms.DataGridViewCell.OnClick(System.Windows.Forms.DataGridViewCellEventArgs) 

    method.

  

   Returns: true if the row will be unshared,otherwise,false. The base 

    System.Windows.Forms.DataGridViewCell class always returns false.
  """
  pass
 def ContentClickUnsharesRow(self,*args):
  """
  ContentClickUnsharesRow(self: DataGridViewCell,e: DataGridViewCellEventArgs) -> bool

  

   Indicates whether the cell's row will be unshared when the cell's content is clicked.

  

   e: The System.Windows.Forms.DataGridViewCellEventArgs containing the data passed to the 

    System.Windows.Forms.DataGridViewCell.OnContentClick(System.Windows.Forms.DataGridViewCellEventAr

    gs) method.

  

   Returns: true if the row will be unshared,otherwise,false. The base 

    System.Windows.Forms.DataGridViewCell class always returns false.
  """
  pass
 def ContentDoubleClickUnsharesRow(self,*args):
  """
  ContentDoubleClickUnsharesRow(self: DataGridViewCell,e: DataGridViewCellEventArgs) -> bool

  

   Indicates whether the cell's row will be unshared when the cell's content is double-clicked.

  

   e: The System.Windows.Forms.DataGridViewCellEventArgs containing the data passed to the 

    System.Windows.Forms.DataGridViewCell.OnContentDoubleClick(System.Windows.Forms.DataGridViewCellE

    ventArgs) method.

  

   Returns: true if the row will be unshared,otherwise,false. The base 

    System.Windows.Forms.DataGridViewCell class always returns false.
  """
  pass
 def CreateAccessibilityInstance(self,*args):
  """
  CreateAccessibilityInstance(self: DataGridViewTopLeftHeaderCell) -> AccessibleObject

  

   Creates a new accessible object for the System.Windows.Forms.DataGridViewTopLeftHeaderCell.

   Returns: A new 

    System.Windows.Forms.DataGridViewTopLeftHeaderCell.DataGridViewTopLeftHeaderCellAccessibleObject 

    for the System.Windows.Forms.DataGridViewTopLeftHeaderCell.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: DataGridViewHeaderCell,disposing: bool)

   Releases the unmanaged resources used by the System.Windows.Forms.DataGridViewHeaderCell and 

    optionally releases the managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def DoubleClickUnsharesRow(self,*args):
  """
  DoubleClickUnsharesRow(self: DataGridViewCell,e: DataGridViewCellEventArgs) -> bool

  

   Indicates whether the cell's row will be unshared when the cell is double-clicked.

  

   e: The System.Windows.Forms.DataGridViewCellEventArgs containing the data passed to the 

    System.Windows.Forms.DataGridViewCell.OnDoubleClick(System.Windows.Forms.DataGridViewCellEventArg

    s) method.

  

   Returns: true if the row will be unshared,otherwise,false. The base 

    System.Windows.Forms.DataGridViewCell class always returns false.
  """
  pass
 def EnterUnsharesRow(self,*args):
  """
  EnterUnsharesRow(self: DataGridViewCell,rowIndex: int,throughMouseClick: bool) -> bool

  

   Indicates whether the parent row will be unshared when the focus moves to the cell.

  

   rowIndex: The index of the cell's parent row.

   throughMouseClick: true if a user action moved focus to the cell; false if a programmatic operation moved focus to 

    the cell.

  

   Returns: true if the row will be unshared; otherwise,false. The base 

    System.Windows.Forms.DataGridViewCell class always returns false.
  """
  pass
 def GetClipboardContent(self,*args):
  """
  GetClipboardContent(self: DataGridViewColumnHeaderCell,rowIndex: int,firstCell: bool,lastCell: bool,inFirstRow: bool,inLastRow: bool,format: str) -> object

  

   Retrieves the formatted value of the cell to copy to the System.Windows.Forms.Clipboard.

  

   rowIndex: The zero-based index of the row containing the cell.

   firstCell: true to indicate that the cell is in the first column of the region defined by the selected 

    cells; otherwise,false.

  

   lastCell: true to indicate that the cell is the last column of the region defined by the selected cells; 

    otherwise,false.

  

   inFirstRow: true to indicate that the cell is in the first row of the region defined by the selected cells; 

    otherwise,false.

  

   inLastRow: true to indicate that the cell is in the last row of the region defined by the selected cells; 

    otherwise,false.

  

   format: The current format string of the cell.

   Returns: A System.Object that represents the value of the cell to copy to the 

    System.Windows.Forms.Clipboard.
  """
  pass
 def GetContentBounds(self,rowIndex):
  """
  GetContentBounds(self: DataGridViewTopLeftHeaderCell,graphics: Graphics,cellStyle: DataGridViewCellStyle,rowIndex: int) -> Rectangle

  

   Returns the bounding rectangle that encloses the cell's content area,which is calculated using 

    the specified System.Drawing.Graphics object and cell style.

  

  

   graphics: The graphics context for the cell.

   cellStyle: The System.Windows.Forms.DataGridViewCellStyle to be applied to the cell.

   rowIndex: The index of the cell's parent row.

   Returns: The System.Drawing.Rectangle that bounds the cell's contents.
  """
  pass
 def GetErrorIconBounds(self,*args):
  """
  GetErrorIconBounds(self: DataGridViewTopLeftHeaderCell,graphics: Graphics,cellStyle: DataGridViewCellStyle,rowIndex: int) -> Rectangle

  

   Returns the bounding rectangle that encloses the cell's error icon,if one is displayed.

  

   graphics: The graphics context for the cell.

   cellStyle: The System.Windows.Forms.DataGridViewCellStyle to be applied to the cell.

   rowIndex: The index of the cell's parent row.

   Returns: The System.Drawing.Rectangle that bounds the cell's error icon,if one is displayed; otherwise,

    System.Drawing.Rectangle.Empty.
  """
  pass
 def GetErrorText(self,*args):
  """
  GetErrorText(self: DataGridViewCell,rowIndex: int) -> str

  

   Returns a string that represents the error for the cell.

  

   rowIndex: The row index of the cell.

   Returns: A string that describes the error for the current System.Windows.Forms.DataGridViewCell.
  """
  pass
 def GetFormattedValue(self,*args):
  """
  GetFormattedValue(self: DataGridViewCell,value: object,rowIndex: int,cellStyle: DataGridViewCellStyle,valueTypeConverter: TypeConverter,formattedValueTypeConverter: TypeConverter,context: DataGridViewDataErrorContexts) -> (object,DataGridViewCellStyle)

  

   Gets the value of the cell as formatted for display.

  

   value: The value to be formatted.

   rowIndex: The index of the cell's parent row.

   cellStyle: The System.Windows.Forms.DataGridViewCellStyle in effect for the cell.

   valueTypeConverter: A System.ComponentModel.TypeConverter associated with the value type that provides custom 

    conversion to the formatted value type,or null if no such custom conversion is needed.

  

   formattedValueTypeConverter: A System.ComponentModel.TypeConverter associated with the formatted value type that provides 

    custom conversion from the value type,or null if no such custom conversion is needed.

  

   context: A bitwise combination of System.Windows.Forms.DataGridViewDataErrorContexts values describing 

    the context in which the formatted value is needed.

  

   Returns: The formatted value of the cell or null if the cell does not belong to a 

    System.Windows.Forms.DataGridView control.
  """
  pass
 def GetPreferredSize(self,*args):
  """
  GetPreferredSize(self: DataGridViewTopLeftHeaderCell,graphics: Graphics,cellStyle: DataGridViewCellStyle,rowIndex: int,constraintSize: Size) -> Size

  

   Calculates the preferred size,in pixels,of the cell.

  

   graphics: The System.Drawing.Graphics used to draw the cell.

   cellStyle: A System.Windows.Forms.DataGridViewCellStyle that represents the style of the cell.

   rowIndex: The zero-based row index of the cell.

   constraintSize: The cell's maximum allowable size.

   Returns: A System.Drawing.Size that represents the preferred size,in pixels,of the cell.
  """
  pass
 def GetSize(self,*args):
  """
  GetSize(self: DataGridViewHeaderCell,rowIndex: int) -> Size

  

   Gets the size of the cell.

  

   rowIndex: The row index of the header cell.

   Returns: A System.Drawing.Size that represents the size of the header cell.
  """
  pass
 def GetValue(self,*args):
  """
  GetValue(self: DataGridViewColumnHeaderCell,rowIndex: int) -> object

  

   Gets the value of the cell.

  

   rowIndex: The index of the cell's parent row.

   Returns: The value contained in the System.Windows.Forms.DataGridViewColumnHeaderCell.
  """
  pass
 def KeyDownUnsharesRow(self,*args):
  """
  KeyDownUnsharesRow(self: DataGridViewCell,e: KeyEventArgs,rowIndex: int) -> bool

  

   Indicates whether the parent row is unshared if the user presses a key while the focus is on the 

    cell.

  

  

   e: A System.Windows.Forms.KeyEventArgs that contains the event data.

   rowIndex: The index of the cell's parent row.

   Returns: true if the row will be unshared,otherwise,false. The base 

    System.Windows.Forms.DataGridViewCell class always returns false.
  """
  pass
 def KeyPressUnsharesRow(self,*args):
  """
  KeyPressUnsharesRow(self: DataGridViewCell,e: KeyPressEventArgs,rowIndex: int) -> bool

  

   Indicates whether a row will be unshared if a key is pressed while a cell in the row has focus.

  

   e: A System.Windows.Forms.KeyPressEventArgs that contains the event data.

   rowIndex: The index of the cell's parent row.

   Returns: true if the row will be unshared,otherwise,false. The base 

    System.Windows.Forms.DataGridViewCell class always returns false.
  """
  pass
 def KeyUpUnsharesRow(self,*args):
  """
  KeyUpUnsharesRow(self: DataGridViewCell,e: KeyEventArgs,rowIndex: int) -> bool

  

   Indicates whether the parent row is unshared when the user releases a key while the focus is on 

    the cell.

  

  

   e: A System.Windows.Forms.KeyEventArgs that contains the event data.

   rowIndex: The index of the cell's parent row.

   Returns: true if the row will be unshared,otherwise,false. The base 

    System.Windows.Forms.DataGridViewCell class always returns false.
  """
  pass
 def LeaveUnsharesRow(self,*args):
  """
  LeaveUnsharesRow(self: DataGridViewCell,rowIndex: int,throughMouseClick: bool) -> bool

  

   Indicates whether a row will be unshared when the focus leaves a cell in the row.

  

   rowIndex: The index of the cell's parent row.

   throughMouseClick: true if a user action moved focus to the cell; false if a programmatic operation moved focus to 

    the cell.

  

   Returns: true if the row will be unshared,otherwise,false. The base 

    System.Windows.Forms.DataGridViewCell class always returns false.
  """
  pass
 def MouseClickUnsharesRow(self,*args):
  """
  MouseClickUnsharesRow(self: DataGridViewCell,e: DataGridViewCellMouseEventArgs) -> bool

  

   Indicates whether a row will be unshared if the user clicks a mouse button while the pointer is 

    on a cell in the row.

  

  

   e: A System.Windows.Forms.DataGridViewCellMouseEventArgs that contains the event data.

   Returns: true if the row will be unshared,otherwise,false. The base 

    System.Windows.Forms.DataGridViewCell class always returns false.
  """
  pass
 def MouseDoubleClickUnsharesRow(self,*args):
  """
  MouseDoubleClickUnsharesRow(self: DataGridViewCell,e: DataGridViewCellMouseEventArgs) -> bool

  

   Indicates whether a row will be unshared if the user double-clicks a cell in the row.

  

   e: A System.Windows.Forms.DataGridViewCellMouseEventArgs that contains the event data.

   Returns: true if the row will be unshared,otherwise,false. The base 

    System.Windows.Forms.DataGridViewCell class always returns false.
  """
  pass
 def MouseDownUnsharesRow(self,*args):
  """
  MouseDownUnsharesRow(self: DataGridViewHeaderCell,e: DataGridViewCellMouseEventArgs) -> bool

  

   Indicates whether a row will be unshared when the mouse button is held down while the pointer is 

    on a cell in the row.

  

  

   e: A System.Windows.Forms.DataGridViewCellMouseEventArgs that contains information about the mouse 

    position.

  

   Returns: true if the user clicks with the left mouse button,visual styles are enabled,and the 

    System.Windows.Forms.DataGridView.EnableHeadersVisualStyles property is true; otherwise,false.
  """
  pass
 def MouseEnterUnsharesRow(self,*args):
  """
  MouseEnterUnsharesRow(self: DataGridViewHeaderCell,rowIndex: int) -> bool

  

   Indicates whether a row will be unshared when the mouse pointer moves over a cell in the row.

  

   rowIndex: The index of the row that the mouse pointer entered.

   Returns: true if visual styles are enabled,and the 

    System.Windows.Forms.DataGridView.EnableHeadersVisualStyles property is true; otherwise,false.
  """
  pass
 def MouseLeaveUnsharesRow(self,*args):
  """
  MouseLeaveUnsharesRow(self: DataGridViewHeaderCell,rowIndex: int) -> bool

  

   Indicates whether a row will be unshared when the mouse pointer leaves the row.

  

   rowIndex: The index of the row that the mouse pointer left.

   Returns: true if the System.Windows.Forms.DataGridViewHeaderCell.ButtonState property value is not 

    System.Windows.Forms.ButtonState.Normal,visual styles are enabled,and the 

    System.Windows.Forms.DataGridView.EnableHeadersVisualStyles property is true; otherwise,false.
  """
  pass
 def MouseMoveUnsharesRow(self,*args):
  """
  MouseMoveUnsharesRow(self: DataGridViewCell,e: DataGridViewCellMouseEventArgs) -> bool

  

   Indicates whether a row will be unshared when the mouse pointer moves over a cell in the row.

  

   e: A System.Windows.Forms.DataGridViewCellMouseEventArgs that contains the event data.

   Returns: true if the row will be unshared,otherwise,false. The base 

    System.Windows.Forms.DataGridViewCell class always returns false.
  """
  pass
 def MouseUpUnsharesRow(self,*args):
  """
  MouseUpUnsharesRow(self: DataGridViewHeaderCell,e: DataGridViewCellMouseEventArgs) -> bool

  

   Indicates whether a row will be unshared when the mouse button is released while the pointer is 

    on a cell in the row.

  

  

   e: A System.Windows.Forms.DataGridViewCellMouseEventArgs that contains information about the mouse 

    position.

  

   Returns: true if the left mouse button was released,visual styles are enabled,and the 

    System.Windows.Forms.DataGridView.EnableHeadersVisualStyles property is true; otherwise,false.
  """
  pass
 def OnClick(self,*args):
  """
  OnClick(self: DataGridViewCell,e: DataGridViewCellEventArgs)

   Called when the cell is clicked.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def OnContentClick(self,*args):
  """
  OnContentClick(self: DataGridViewCell,e: DataGridViewCellEventArgs)

   Called when the cell's contents are clicked.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def OnContentDoubleClick(self,*args):
  """
  OnContentDoubleClick(self: DataGridViewCell,e: DataGridViewCellEventArgs)

   Called when the cell's contents are double-clicked.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def OnDataGridViewChanged(self,*args):
  """
  OnDataGridViewChanged(self: DataGridViewCell)

   Called when the System.Windows.Forms.DataGridViewElement.DataGridView property of the cell 

    changes.
  """
  pass
 def OnDoubleClick(self,*args):
  """
  OnDoubleClick(self: DataGridViewCell,e: DataGridViewCellEventArgs)

   Called when the cell is double-clicked.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def OnEnter(self,*args):
  """
  OnEnter(self: DataGridViewCell,rowIndex: int,throughMouseClick: bool)

   Called when the focus moves to a cell.

  

   rowIndex: The index of the cell's parent row.

   throughMouseClick: true if a user action moved focus to the cell; false if a programmatic operation moved focus to 

    the cell.
  """
  pass
 def OnKeyDown(self,*args):
  """
  OnKeyDown(self: DataGridViewCell,e: KeyEventArgs,rowIndex: int)

   Called when a character key is pressed while the focus is on a cell.

  

   e: A System.Windows.Forms.KeyEventArgs that contains the event data.

   rowIndex: The index of the cell's parent row.
  """
  pass
 def OnKeyPress(self,*args):
  """
  OnKeyPress(self: DataGridViewCell,e: KeyPressEventArgs,rowIndex: int)

   Called when a key is pressed while the focus is on a cell.

  

   e: A System.Windows.Forms.KeyPressEventArgs that contains the event data.

   rowIndex: The index of the cell's parent row.
  """
  pass
 def OnKeyUp(self,*args):
  """
  OnKeyUp(self: DataGridViewCell,e: KeyEventArgs,rowIndex: int)

   Called when a character key is released while the focus is on a cell.

  

   e: A System.Windows.Forms.KeyEventArgs that contains the event data.

   rowIndex: The index of the cell's parent row.
  """
  pass
 def OnLeave(self,*args):
  """
  OnLeave(self: DataGridViewCell,rowIndex: int,throughMouseClick: bool)

   Called when the focus moves from a cell.

  

   rowIndex: The index of the cell's parent row.

   throughMouseClick: true if a user action moved focus from the cell; false if a programmatic operation moved focus 

    from the cell.
  """
  pass
 def OnMouseClick(self,*args):
  """
  OnMouseClick(self: DataGridViewCell,e: DataGridViewCellMouseEventArgs)

   Called when the user clicks a mouse button while the pointer is on a cell.

  

   e: A System.Windows.Forms.DataGridViewCellMouseEventArgs that contains the event data.
  """
  pass
 def OnMouseDoubleClick(self,*args):
  """
  OnMouseDoubleClick(self: DataGridViewCell,e: DataGridViewCellMouseEventArgs)

   Called when the user double-clicks a mouse button while the pointer is on a cell.

  

   e: A System.Windows.Forms.DataGridViewCellMouseEventArgs that contains the event data.
  """
  pass
 def OnMouseDown(self,*args):
  """
  OnMouseDown(self: DataGridViewHeaderCell,e: DataGridViewCellMouseEventArgs)

   Called when the mouse button is held down while the pointer is on a cell.

  

   e: A System.Windows.Forms.DataGridViewCellMouseEventArgs that contains information about the mouse 

    position.
  """
  pass
 def OnMouseEnter(self,*args):
  """
  OnMouseEnter(self: DataGridViewHeaderCell,rowIndex: int)

   Called when the mouse pointer enters the cell.

  

   rowIndex: The index of the row containing the cell.
  """
  pass
 def OnMouseLeave(self,*args):
  """
  OnMouseLeave(self: DataGridViewHeaderCell,rowIndex: int)

   Called when the mouse pointer leaves the cell.

  

   rowIndex: The index of the row containing the cell.
  """
  pass
 def OnMouseMove(self,*args):
  """
  OnMouseMove(self: DataGridViewCell,e: DataGridViewCellMouseEventArgs)

   Called when the mouse pointer moves within a cell.

  

   e: A System.Windows.Forms.DataGridViewCellMouseEventArgs that contains the event data.
  """
  pass
 def OnMouseUp(self,*args):
  """
  OnMouseUp(self: DataGridViewHeaderCell,e: DataGridViewCellMouseEventArgs)

   Called when the mouse button is released while the pointer is over the cell.

  

   e: A System.Windows.Forms.DataGridViewCellMouseEventArgs that contains information about the mouse 

    position.
  """
  pass
 def Paint(self,*args):
  """
  Paint(self: DataGridViewTopLeftHeaderCell,graphics: Graphics,clipBounds: Rectangle,cellBounds: Rectangle,rowIndex: int,cellState: DataGridViewElementStates,value: object,formattedValue: object,errorText: str,cellStyle: DataGridViewCellStyle,advancedBorderStyle: DataGridViewAdvancedBorderStyle,paintParts: DataGridViewPaintParts)

   Paints the current System.Windows.Forms.DataGridViewTopLeftHeaderCell.

  

   graphics: The System.Drawing.Graphics used to paint the System.Windows.Forms.DataGridViewCell.

   clipBounds: A System.Drawing.Rectangle that represents the area of the System.Windows.Forms.DataGridView 

    that needs to be repainted.

  

   cellBounds: A System.Drawing.Rectangle that contains the bounds of the System.Windows.Forms.DataGridViewCell 

    that is being painted.

  

   rowIndex: The row index of the cell that is being painted.

   cellState: A bitwise combination of System.Windows.Forms.DataGridViewElementStates values that specifies 

    the state of the cell.

  

   value: The data of the System.Windows.Forms.DataGridViewCell that is being painted.

   formattedValue: The formatted data of the System.Windows.Forms.DataGridViewCell that is being painted.

   errorText: An error message that is associated with the cell.

   cellStyle: A System.Windows.Forms.DataGridViewCellStyle that contains formatting and style information 

    about the cell.

  

   advancedBorderStyle: A System.Windows.Forms.DataGridViewAdvancedBorderStyle that contains border styles for the cell 

    that is being painted.

  

   paintParts: A bitwise combination of the System.Windows.Forms.DataGridViewPaintParts values that specifies 

    which parts of the cell need to be painted.
  """
  pass
 def PaintBorder(self,*args):
  """
  PaintBorder(self: DataGridViewTopLeftHeaderCell,graphics: Graphics,clipBounds: Rectangle,bounds: Rectangle,cellStyle: DataGridViewCellStyle,advancedBorderStyle: DataGridViewAdvancedBorderStyle)

   graphics: The System.Drawing.Graphics used to paint the border.

   clipBounds: A System.Drawing.Rectangle that represents the area of the System.Windows.Forms.DataGridView 

    that needs to be repainted.

  

   bounds: A System.Drawing.Rectangle that contains the area of the border that is being painted.

   cellStyle: A System.Windows.Forms.DataGridViewCellStyle that contains formatting and style information 

    about the current cell.

  

   advancedBorderStyle: A System.Windows.Forms.DataGridViewAdvancedBorderStyle that contains border styles of the border 

    that is being painted.
  """
  pass
 def PaintErrorIcon(self,*args):
  """
  PaintErrorIcon(self: DataGridViewCell,graphics: Graphics,clipBounds: Rectangle,cellValueBounds: Rectangle,errorText: str)

   Paints the error icon of the current System.Windows.Forms.DataGridViewCell.

  

   graphics: The System.Drawing.Graphics used to paint the border.

   clipBounds: A System.Drawing.Rectangle that represents the area of the System.Windows.Forms.DataGridView 

    that needs to be repainted.

  

   cellValueBounds: The bounding System.Drawing.Rectangle that encloses the cell's content area.

   errorText: An error message that is associated with the cell.
  """
  pass
 def RaiseCellClick(self,*args):
  """
  RaiseCellClick(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellClick event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseCellContentClick(self,*args):
  """
  RaiseCellContentClick(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellContentClick event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseCellContentDoubleClick(self,*args):
  """
  RaiseCellContentDoubleClick(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellContentDoubleClick event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseCellValueChanged(self,*args):
  """
  RaiseCellValueChanged(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellValueChanged event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseDataError(self,*args):
  """
  RaiseDataError(self: DataGridViewElement,e: DataGridViewDataErrorEventArgs)

   Raises the System.Windows.Forms.DataGridView.DataError event.

  

   e: A System.Windows.Forms.DataGridViewDataErrorEventArgs that contains the event data.
  """
  pass
 def RaiseMouseWheel(self,*args):
  """
  RaiseMouseWheel(self: DataGridViewElement,e: MouseEventArgs)

   Raises the System.Windows.Forms.Control.MouseWheel event.

  

   e: A System.Windows.Forms.MouseEventArgs that contains the event data.
  """
  pass
 def SetValue(self,*args):
  """
  SetValue(self: DataGridViewColumnHeaderCell,rowIndex: int,value: object) -> bool

  

   Sets the value of the cell.

  

   rowIndex: The index of the cell's parent row.

   value: The cell value to set.

   Returns: true if the value has been set; otherwise false.
  """
  pass
 def ToString(self):
  """
  ToString(self: DataGridViewTopLeftHeaderCell) -> str

  

   Returns the string representation of the cell.

   Returns: A string that represents the current cell.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __str__(self,*args):
  pass
 ButtonState=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the buttonlike visual state of the header cell.



"""


 DataGridViewTopLeftHeaderCellAccessibleObject=None




class LayoutInformation(object):
 """ Defines methods that provide additional information about the layout state of an element. """
 @staticmethod
 def GetLayoutClip(element):
  """
  GetLayoutClip(element: FrameworkElement) -> Geometry

  

   Returns a System.Windows.Media.Geometry that represents the visible region of an element.

  

   element: The System.Windows.FrameworkElement whose layout clip is desired.

   Returns: A System.Windows.Media.Geometry that represents the visible region of an element.
  """
  pass
 @staticmethod
 def GetLayoutExceptionElement(dispatcher):
  """
  GetLayoutExceptionElement(dispatcher: Dispatcher) -> UIElement

  

   Returns a System.Windows.UIElement that was being processed by the layout engine at the moment 

    of an unhandled exception.

  

  

   dispatcher: The System.Windows.Threading.Dispatcher object that defines the scope of the operation. There is 

    one dispatcher per layout engine instance.

  

   Returns: A System.Windows.UIElement that was being processed by the layout engine at the moment of an 

    unhandled exception.
  """
  pass
 @staticmethod
 def GetLayoutSlot(element):
  """
  GetLayoutSlot(element: FrameworkElement) -> Rect

  

   Returns a System.Windows.Rect that represents the layout partition that is reserved for a child 

    element.

  

  

   element: The System.Windows.FrameworkElement whose layout slot is desired.

   Returns: A System.Windows.Rect that represents the layout slot of the element.
  """
  pass
 __all__=[
  'GetLayoutClip',
  'GetLayoutExceptionElement',
  'GetLayoutSlot',
 ]




class PaintEventArgs(EventArgs,IDisposable):
 """
 Provides data for the System.Windows.Forms.Control.Paint event.

 

 PaintEventArgs(graphics: Graphics,clipRect: Rectangle)
 """
 def Dispose(self):
  """
  Dispose(self: PaintEventArgs)

   Releases all resources used by the System.Windows.Forms.PaintEventArgs.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,graphics,clipRect):
  """ __new__(cls: type,graphics: Graphics,clipRect: Rectangle) """
  pass
 ClipRectangle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the rectangle in which to paint.



Get: ClipRectangle(self: PaintEventArgs) -> Rectangle



"""

 Graphics=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the graphics used to paint.



Get: Graphics(self: PaintEventArgs) -> Graphics



"""





class _Type:
 """ Exposes the public members of the System.Type class to the unmanaged code. """
 def Equals(self,*__args):
  """
  Equals(self: _Type,o: Type) -> bool

  

   Provides COM objects with version-independent access to the System.Type.Equals(System.Type) 

    method.

  

  

   o: The System.Type whose underlying system type is to be compared with the underlying system type 

    of the current System.Type.

  

   Returns: true if the underlying system type of o is the same as the underlying system type of the current 

    System.Type; otherwise,false.

  

  Equals(self: _Type,other: object) -> bool

  

   Provides COM objects with version-independent access to the System.Type.Equals(System.Object) 

    method.

  

  

   other: The System.Object whose underlying system type is to be compared with the underlying system type 

    of the current System.Type.

  

   Returns: true if the underlying system type of o is the same as the underlying system type of the current 

    System.Type; otherwise,false.
  """
  pass
 def FindInterfaces(self,filter,filterCriteria):
  """
  FindInterfaces(self: _Type,filter: TypeFilter,filterCriteria: object) -> Array[Type]

  

   Provides COM objects with version-independent access to the 

    System.Type.FindInterfaces(System.Reflection.TypeFilter,System.Object) method.

  

  

   filter: The System.Reflection.TypeFilter delegate that compares the interfaces against filterCriteria.

   filterCriteria: The search criteria that determines whether an interface should be included in the returned 

    array.

  

   Returns: An array of System.Type objects representing a filtered list of the interfaces implemented or 

    inherited by the current System.Type.-or- An empty array of type System.Type,if no interfaces 

    matching the filter are implemented or inherited by the current System.Type.
  """
  pass
 def FindMembers(self,memberType,bindingAttr,filter,filterCriteria):
  """
  FindMembers(self: _Type,memberType: MemberTypes,bindingAttr: BindingFlags,filter: MemberFilter,filterCriteria: object) -> Array[MemberInfo]

  

   Provides COM objects with version-independent access to the 

    System.Type.FindMembers(System.Reflection.MemberTypes,System.Reflection.BindingFlags,System.Refle

    ction.MemberFilter,System.Object) method.

  

  

   memberType: A MemberTypes object indicating the type of member to search for.

   bindingAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return null.

  

   filter: The delegate that does the comparisons,returning true if the member currently being inspected 

    matches the filterCriteria and false otherwise. You can use the FilterAttribute,FilterName,and 

    FilterNameIgnoreCase delegates supplied by this class. The first uses the fields of 

    FieldAttributes,MethodAttributes,and MethodImplAttributes as search criteria,and the other 

    two delegates use String objects as the search criteria.

  

   filterCriteria: The search criteria that determines whether a member is returned in the array of MemberInfo 

    objects.The fields of FieldAttributes,MethodAttributes,and MethodImplAttributes can be used in 

    conjunction with the FilterAttribute delegate supplied by this class.

  

   Returns: A filtered array of System.Reflection.MemberInfo objects of the specified member type.-or- An 

    empty array of type System.Reflection.MemberInfo,if the current System.Type does not have 

    members of type memberType that match the filter criteria.
  """
  pass
 def GetArrayRank(self):
  """
  GetArrayRank(self: _Type) -> int

  

   Provides COM objects with version-independent access to the System.Type.GetArrayRank method.

   Returns: An System.Int32 containing the number of dimensions in the current System.Type.
  """
  pass
 def GetConstructor(self,*__args):
  """
  GetConstructor(self: _Type,types: Array[Type]) -> ConstructorInfo

  

   Provides COM objects with version-independent access to the 

    System.Type.GetConstructor(System.Type[]) method.

  

  

   types: An array of System.Type objects representing the number,order,and type of the parameters for 

    the desired constructor.-or- An empty array of System.Type objects,to get a constructor that 

    takes no parameters. Such an empty array is provided by the static field System.Type.EmptyTypes.

  

   Returns: A System.Reflection.ConstructorInfo object representing the public instance constructor whose 

    parameters match the types in the parameter type array,if found; otherwise,null.

  

  GetConstructor(self: _Type,bindingAttr: BindingFlags,binder: Binder,types: Array[Type],modifiers: Array[ParameterModifier]) -> ConstructorInfo

  

   Provides COM objects with version-independent access to the 

    System.Type.GetConstructor(System.Reflection.BindingFlags,System.Reflection.Binder,System.Type[],

    System.Reflection.ParameterModifier[]) method.

  

  

   bindingAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return null.

  

   binder: A System.Reflection.Binder object that defines a set of properties and enables binding,which 

    can involve selection of an overloaded method,coercion of argument types,and invocation of a 

    member through reflection.-or- null,to use the System.Type.DefaultBinder.

  

   types: An array of System.Type objects representing the number,order,and type of the parameters for 

    the constructor to get.-or- An empty array of the type System.Type (that is,Type[] types=new 

    Type[0]) to get a constructor that takes no parameters.-or- System.Type.EmptyTypes.

  

   modifiers: An array of System.Reflection.ParameterModifier objects representing the attributes associated 

    with the corresponding element in the parameter type array. The default binder does not process 

    this parameter.

  

   Returns: A System.Reflection.ConstructorInfo object representing the constructor that matches the 

    specified requirements,if found; otherwise,null.

  

  GetConstructor(self: _Type,bindingAttr: BindingFlags,binder: Binder,callConvention: CallingConventions,types: Array[Type],modifiers: Array[ParameterModifier]) -> ConstructorInfo

  

   Provides COM objects with version-independent access to the 

    System.Type.GetConstructor(System.Reflection.BindingFlags,System.Reflection.Binder,System.Reflect

    ion.CallingConventions,System.Type[],System.Reflection.ParameterModifier[]) method.

  

  

   bindingAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return null.

  

   binder: A System.Reflection.Binder object that defines a set of properties and enables binding,which 

    can involve selection of an overloaded method,coercion of argument types,and invocation of a 

    member through reflection.-or- null,to use the System.Type.DefaultBinder.

  

   callConvention: The System.Reflection.CallingConventions object that specifies the set of rules to use regarding 

    the order and layout of arguments,how the return value is passed,what registers are used for 

    arguments,and the stack is cleaned up.

  

   types: An array of System.Type objects representing the number,order,and type of the parameters for 

    the constructor to get.-or- An empty array of the type System.Type (that is,Type[] types=new 

    Type[0]) to get a constructor that takes no parameters.

  

   modifiers: An array of System.Reflection.ParameterModifier objects representing the attributes associated 

    with the corresponding element in the types array. The default binder does not process this 

    parameter.

  

   Returns: A System.Reflection.ConstructorInfo object representing the constructor that matches the 

    specified requirements,if found; otherwise,null.
  """
  pass
 def GetConstructors(self,bindingAttr=None):
  """
  GetConstructors(self: _Type) -> Array[ConstructorInfo]

  

   Provides COM objects with version-independent access to the System.Type.GetConstructors method.

   Returns: An array of System.Reflection.ConstructorInfo objects representing all the public instance 

    constructors defined for the current System.Type,but not including the type initializer (static 

    constructor). If no public instance constructors are defined for the current System.Type,or if 

    the current System.Type represents a type parameter of a generic type or method definition,an 

    empty array of type System.Reflection.ConstructorInfo is returned.

  

  GetConstructors(self: _Type,bindingAttr: BindingFlags) -> Array[ConstructorInfo]

  

   Provides COM objects with version-independent access to the 

    System.Type.GetConstructors(System.Reflection.BindingFlags) method.

  

  

   bindingAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return null.

  

   Returns: An array of System.Reflection.ConstructorInfo objects representing all constructors defined for 

    the current System.Type that match the specified binding constraints,including the type 

    initializer if it is defined. Returns an empty array of type System.Reflection.ConstructorInfo 

    if no constructors are defined for the current System.Type,if none of the defined constructors 

    match the binding constraints,or if the current System.Type represents a type parameter of a 

    generic type or method definition.
  """
  pass
 def GetCustomAttributes(self,*__args):
  """
  GetCustomAttributes(self: _Type,inherit: bool) -> Array[object]

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetCustomAttributes(System.Boolean) method.

  

  

   inherit: Specifies whether to search this member's inheritance chain to find the attributes.

   Returns: An array of custom attributes applied to this member,or an array with zero (0) elements if no 

    attributes have been applied.

  

  GetCustomAttributes(self: _Type,attributeType: Type,inherit: bool) -> Array[object]

  

   Provides COM objects with version-independent access to the 

    System.Reflection.MemberInfo.GetCustomAttributes(System.Type,System.Boolean) method.

  

  

   attributeType: The type of attribute to search for. Only attributes that are assignable to this type are 

    returned.

  

   inherit: Specifies whether to search this member's inheritance chain to find the attributes.

   Returns: An array of custom attributes applied to this member,or an array with zero (0) elements if no 

    attributes have been applied.
  """
  pass
 def GetDefaultMembers(self):
  """
  GetDefaultMembers(self: _Type) -> Array[MemberInfo]

  

   Provides COM objects with version-independent access to the System.Type.GetDefaultMembers method.

   Returns: An array of System.Reflection.MemberInfo objects representing all default members of the current 

    System.Type.-or- An empty array of type System.Reflection.MemberInfo,if the current System.Type 

    does not have default members.
  """
  pass
 def GetElementType(self):
  """
  GetElementType(self: _Type) -> Type

  

   Provides COM objects with version-independent access to the System.Type.GetElementType method.

   Returns: The System.Type of the object encompassed or referred to by the current array,pointer or 

    reference type.-or- null if the current System.Type is not an array or a pointer,or is not 

    passed by reference,or represents a generic type or a type parameter of a generic type or 

    method definition.
  """
  pass
 def GetEvent(self,name,bindingAttr=None):
  """
  GetEvent(self: _Type,name: str) -> EventInfo

  

   Provides COM objects with version-independent access to the System.Type.GetEvent(System.String) 

    method.

  

  

   name: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return null.

  

   Returns: An array of System.Reflection.EventInfo objects representing all events that are declared or 

    inherited by the current System.Type that match the specified binding constraints.-or- An empty 

    array of type System.Reflection.EventInfo,if the current System.Type does not have events,or 

    if none of the events match the binding constraints.

  

  GetEvent(self: _Type,name: str,bindingAttr: BindingFlags) -> EventInfo

  

   Provides COM objects with version-independent access to the 

    System.Type.GetEvent(System.String,System.Reflection.BindingFlags) method.

  

  

   name: The System.String containing the name of an event that is declared or inherited by the current 

    System.Type.

  

   bindingAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return null.

  

   Returns: The System.Reflection.EventInfo object representing the specified event that is declared or 

    inherited by the current System.Type,if found; otherwise,null.
  """
  pass
 def GetEvents(self,bindingAttr=None):
  """
  GetEvents(self: _Type,bindingAttr: BindingFlags) -> Array[EventInfo]

  

   Provides COM objects with version-independent access to the 

    System.Type.GetEvents(System.Reflection.BindingFlags) method.

  

  

   bindingAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return null.

  

   Returns: An array of System.Reflection.EventInfo objects representing all events that are declared or 

    inherited by the current System.Type that match the specified binding constraints.-or- An empty 

    array of type System.Reflection.EventInfo,if the current System.Type does not have events,or 

    if none of the events match the binding constraints.

  

  GetEvents(self: _Type) -> Array[EventInfo]

  

   Provides COM objects with version-independent access to the System.Type.GetEvents method.

   Returns: An array of System.Reflection.EventInfo objects representing all the public events that are 

    declared or inherited by the current System.Type.-or- An empty array of type 

    System.Reflection.EventInfo,if the current System.Type does not have public events.
  """
  pass
 def GetField(self,name,bindingAttr=None):
  """
  GetField(self: _Type,name: str) -> FieldInfo

  

   Provides COM objects with version-independent access to the System.Type.GetField(System.String) 

    method.

  

  

   name: The System.String containing the name of the data field to get.

   Returns: A System.Reflection.FieldInfo object representing the public field with the specified name,if 

    found; otherwise,null.

  

  GetField(self: _Type,name: str,bindingAttr: BindingFlags) -> FieldInfo

  

   Provides COM objects with version-independent access to the 

    System.Type.GetField(System.String,System.Reflection.BindingFlags) method.

  

  

   name: The System.String containing the name of the data field to get.

   bindingAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return null.

  

   Returns: A System.Reflection.FieldInfo object representing the field that matches the specified 

    requirements,if found; otherwise,null.
  """
  pass
 def GetFields(self,bindingAttr=None):
  """
  GetFields(self: _Type) -> Array[FieldInfo]

  

   Provides COM objects with version-independent access to the System.Type.GetFields method.

   Returns: An array of System.Reflection.FieldInfo objects representing all the public fields defined for 

    the current System.Type.-or- An empty array of type System.Reflection.FieldInfo,if no public 

    fields are defined for the current System.Type.

  

  GetFields(self: _Type,bindingAttr: BindingFlags) -> Array[FieldInfo]

  

   Provides COM objects with version-independent access to the 

    System.Type.GetFields(System.Reflection.BindingFlags) method.

  

  

   bindingAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return null.

  

   Returns: An array of System.Reflection.FieldInfo objects representing all fields defined for the current 

    System.Type that match the specified binding constraints.-or- An empty array of type 

    System.Reflection.FieldInfo,if no fields are defined for the current System.Type,or if none of 

    the defined fields match the binding constraints.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: _Type) -> int

  

   Provides COM objects with version-independent access to the System.Type.GetHashCode method.

   Returns: An System.Int32 containing the hash code for this instance.
  """
  pass
 def GetIDsOfNames(self,riid,rgszNames,cNames,lcid,rgDispId):
  """
  GetIDsOfNames(self: _Type,riid: Guid,rgszNames: IntPtr,cNames: UInt32,lcid: UInt32,rgDispId: IntPtr) -> Guid

  

   Maps a set of names to a corresponding set of dispatch identifiers.

  

   riid: Reserved for future use. Must be IID_NULL.

   rgszNames: Passed-in array of names to be mapped.

   cNames: Count of the names to be mapped.

   lcid: The locale context in which to interpret the names.

   rgDispId: Caller-allocated array that receives the IDs corresponding to the names.
  """
  pass
 def GetInterface(self,name,ignoreCase=None):
  """
  GetInterface(self: _Type,name: str) -> Type

  

   Provides COM objects with version-independent access to the 

    System.Type.GetInterface(System.String) method.

  

  

   name: The System.String containing the name of the interface to get. For generic interfaces,this is 

    the mangled name.

  

   Returns: A System.Type object representing the interface with the specified name,implemented or 

    inherited by the current System.Type,if found; otherwise,null.

  

  GetInterface(self: _Type,name: str,ignoreCase: bool) -> Type

  

   Provides COM objects with version-independent access to the 

    System.Type.GetInterface(System.String,System.Boolean) method.

  

  

   name: The System.String containing the name of the interface to get. For generic interfaces,this is 

    the mangled name.

  

   ignoreCase: true to perform a case-insensitive search for name.-or- false to perform a case-sensitive search 

    for name.

  

   Returns: A System.Type object representing the interface with the specified name,implemented or 

    inherited by the current System.Type,if found; otherwise,null.
  """
  pass
 def GetInterfaceMap(self,interfaceType):
  """
  GetInterfaceMap(self: _Type,interfaceType: Type) -> InterfaceMapping

  

   Provides COM objects with version-independent access to the 

    System.Type.GetInterfaceMap(System.Type) method.

  

  

   interfaceType: The System.Type of the interface of which to retrieve a mapping.

   Returns: An System.Reflection.InterfaceMapping object representing the interface mapping for 

    interfaceType.
  """
  pass
 def GetInterfaces(self):
  """
  GetInterfaces(self: _Type) -> Array[Type]

  

   Provides COM objects with version-independent access to the System.Type.GetInterfaces method.

   Returns: An array of System.Type objects representing all the interfaces implemented or inherited by the 

    current System.Type.-or- An empty array of type System.Type,if no interfaces are implemented or 

    inherited by the current System.Type.
  """
  pass
 def GetMember(self,name,*__args):
  """
  GetMember(self: _Type,name: str) -> Array[MemberInfo]

  

   Provides COM objects with version-independent access to the System.Type.GetMember(System.String) 

    method.

  

  

   name: The System.String containing the name of the public members to get.

   Returns: An array of System.Reflection.MemberInfo objects representing the public members with the 

    specified name,if found; otherwise,an empty array.

  

  GetMember(self: _Type,name: str,bindingAttr: BindingFlags) -> Array[MemberInfo]

  

   Provides COM objects with version-independent access to the 

    System.Type.GetMember(System.String,System.Reflection.BindingFlags) method.

  

  

   name: The System.String containing the name of the members to get.

   bindingAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return an empty array.

  

   Returns: An array of System.Reflection.MemberInfo objects representing the public members with the 

    specified name,if found; otherwise,an empty array.

  

  GetMember(self: _Type,name: str,type: MemberTypes,bindingAttr: BindingFlags) -> Array[MemberInfo]

  

   Provides COM objects with version-independent access to the 

    System.Type.GetMember(System.String,System.Reflection.MemberTypes,System.Reflection.BindingFlags)

     method.

  

  

   name: The System.String containing the name of the members to get.

   type: The System.Reflection.MemberTypes value to search for.

   bindingAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return an empty array.

  

   Returns: An array of System.Reflection.MemberInfo objects representing the public members with the 

    specified name,if found; otherwise,an empty array.
  """
  pass
 def GetMembers(self,bindingAttr=None):
  """
  GetMembers(self: _Type) -> Array[MemberInfo]

  

   Provides COM objects with version-independent access to the System.Type.GetMembers method.

   Returns: An array of System.Reflection.MemberInfo objects representing all the public members of the 

    current System.Type.-or- An empty array of type System.Reflection.MemberInfo,if the current 

    System.Type does not have public members.

  

  GetMembers(self: _Type,bindingAttr: BindingFlags) -> Array[MemberInfo]

  

   Provides COM objects with version-independent access to the 

    System.Type.GetMembers(System.Reflection.BindingFlags) method.

  

  

   bindingAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return null.

  

   Returns: An array of System.Reflection.MemberInfo objects representing all members defined for the 

    current System.Type that match the specified binding constraints.-or- An empty array of type 

    System.Reflection.MemberInfo,if no members are defined for the current System.Type,or if none 

    of the defined members match the binding constraints.
  """
  pass
 def GetMethod(self,name,*__args):
  """
  GetMethod(self: _Type,name: str,types: Array[Type],modifiers: Array[ParameterModifier]) -> MethodInfo

  

   Provides COM objects with version-independent access to the 

    System.Type.GetMethod(System.String,System.Type[],System.Reflection.ParameterModifier[]) method.

  

  

   name: The System.String containing the name of the public method to get.

   types: An array of System.Type objects representing the number,order,and type of the parameters for 

    the method to get.-or- An empty array of the type System.Type (that is,Type[] types=new 

    Type[0]) to get a method that takes no parameters.

  

   modifiers: An array of System.Reflection.ParameterModifier objects representing the attributes associated 

    with the corresponding element in the types array. The default binder does not process this 

    parameter.

  

   Returns: A System.Reflection.MethodInfo object representing the public method that matches the specified 

    requirements,if found; otherwise,null.

  

  GetMethod(self: _Type,name: str,types: Array[Type]) -> MethodInfo

  

   Provides COM objects with version-independent access to the 

    System.Type.GetMethod(System.String,System.Type[]) method.

  

  

   name: The System.String containing the name of the public method to get.

   types: An array of System.Type objects representing the number,order,and type of the parameters for 

    the method to get.-or- An empty array of the type System.Type (that is,Type[] types=new 

    Type[0]) to get a method that takes no parameters.

  

   Returns: A System.Reflection.MethodInfo object representing the public method whose parameters match the 

    specified argument types,if found; otherwise,null.

  

  GetMethod(self: _Type,name: str) -> MethodInfo

  

   Provides COM objects with version-independent access to the System.Type.GetMethod(System.String) 

    method.

  

  

   name: The System.String containing the name of the public method to get.

   Returns: A System.Reflection.MethodInfo object representing the public method with the specified name,if 

    found; otherwise,null.

  

  GetMethod(self: _Type,name: str,bindingAttr: BindingFlags,binder: Binder,types: Array[Type],modifiers: Array[ParameterModifier]) -> MethodInfo

  

   Provides COM objects with version-independent access to the 

    System.Type.GetMethod(System.String,System.Reflection.BindingFlags,System.Reflection.Binder,Syste

    m.Type[],System.Reflection.ParameterModifier[]) method.

  

  

   name: The System.String containing the name of the method to get.

   bindingAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return null.

  

   binder: A System.Reflection.Binder object that defines a set of properties and enables binding,which 

    can involve selection of an overloaded method,coercion of argument types,and invocation of a 

    member through reflection.-or- null,to use the System.Type.DefaultBinder.

  

   types: An array of System.Type objects representing the number,order,and type of the parameters for 

    the method to get.-or- An empty array of the type System.Type (that is,Type[] types=new 

    Type[0]) to get a method that takes no parameters.

  

   modifiers: An array of System.Reflection.ParameterModifier objects representing the attributes associated 

    with the corresponding element in the types array. The default binder does not process this 

    parameter.

  

   Returns: A System.Reflection.MethodInfo object representing the method that matches the specified 

    requirements,if found; otherwise,null.

  

  GetMethod(self: _Type,name: str,bindingAttr: BindingFlags) -> MethodInfo

  

   Provides COM objects with version-independent access to the 

    System.Type.GetMethod(System.String,System.Reflection.BindingFlags) method.

  

  

   name: The System.String containing the name of the method to get.

   bindingAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return null.

  

   Returns: A System.Reflection.MethodInfo object representing the method that matches the specified 

    requirements,if found; otherwise,null.

  

  GetMethod(self: _Type,name: str,bindingAttr: BindingFlags,binder: Binder,callConvention: CallingConventions,types: Array[Type],modifiers: Array[ParameterModifier]) -> MethodInfo

  

   Provides COM objects with version-independent access to the 

    System.Type.GetMethod(System.String,System.Reflection.BindingFlags,System.Reflection.Binder,Syste

    m.Reflection.CallingConventions,System.Type[],System.Reflection.ParameterModifier[]) method.

  

  

   name: The System.String containing the name of the method to get.

   bindingAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return null.

  

   binder: A System.Reflection.Binder object that defines a set of properties and enables binding,which 

    can involve selection of an overloaded method,coercion of argument types,and invocation of a 

    member through reflection.-or- null,to use the System.Type.DefaultBinder.

  

   callConvention: The System.Reflection.CallingConventions object that specifies the set of rules to use regarding 

    the order and layout of arguments,how the return value is passed,what registers are used for 

    arguments,and how the stack is cleaned up.

  

   types: An array of System.Type objects representing the number,order,and type of the parameters for 

    the method to get.-or- An empty array of the type System.Type (that is,Type[] types=new 

    Type[0]) to get a method that takes no parameters.

  

   modifiers: An array of System.Reflection.ParameterModifier objects representing the attributes associated 

    with the corresponding element in the types array. The default binder does not process this 

    parameter.

  

   Returns: A System.Reflection.MethodInfo object representing the method that matches the specified 

    requirements,if found; otherwise,null.
  """
  pass
 def GetMethods(self,bindingAttr=None):
  """
  GetMethods(self: _Type) -> Array[MethodInfo]

  

   Provides COM objects with version-independent access to the System.Type.GetMethods method.

   Returns: An array of System.Reflection.MethodInfo objects representing all the public methods defined for 

    the current System.Type.-or- An empty array of type System.Reflection.MethodInfo,if no public 

    methods are defined for the current System.Type.

  

  GetMethods(self: _Type,bindingAttr: BindingFlags) -> Array[MethodInfo]

  

   Provides COM objects with version-independent access to the 

    System.Type.GetMethods(System.Reflection.BindingFlags) method.

  

  

   bindingAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return null.

  

   Returns: An array of System.Reflection.MethodInfo objects representing all methods defined for the 

    current System.Type that match the specified binding constraints.-or- An empty array of type 

    System.Reflection.MethodInfo,if no methods are defined for the current System.Type,or if none 

    of the defined methods match the binding constraints.
  """
  pass
 def GetNestedType(self,name,bindingAttr=None):
  """
  GetNestedType(self: _Type,name: str) -> Type

  

   Provides COM objects with version-independent access to the 

    System.Type.GetNestedType(System.String) method.

  

  

   name: The string containing the name of the nested type to get.

   Returns: A System.Type object representing the public nested type with the specified name,if found; 

    otherwise,null.

  

  GetNestedType(self: _Type,name: str,bindingAttr: BindingFlags) -> Type

  

   Provides COM objects with version-independent access to the 

    System.Type.GetNestedType(System.String,System.Reflection.BindingFlags) method.

  

  

   name: The string containing the name of the nested type to get.

   bindingAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return null.

  

   Returns: A System.Type object representing the nested type that matches the specified requirements,if 

    found; otherwise,null.
  """
  pass
 def GetNestedTypes(self,bindingAttr=None):
  """
  GetNestedTypes(self: _Type) -> Array[Type]

  

   Provides COM objects with version-independent access to the System.Type.GetNestedTypes method.

   Returns: An array of System.Type objects representing all the types nested within the current 

    System.Type.-or- An empty array of type System.Type,if no types are nested within the current 

    System.Type.

  

  GetNestedTypes(self: _Type,bindingAttr: BindingFlags) -> Array[Type]

  

   Provides COM objects with version-independent access to the 

    System.Type.GetNestedTypes(System.Reflection.BindingFlags) method,and searches for the types 

    nested within the current System.Type,using the specified binding constraints.

  

  

   bindingAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return null.

  

   Returns: An array of System.Type objects representing all the types nested within the current System.Type 

    that match the specified binding constraints.-or- An empty array of type System.Type,if no 

    types are nested within the current System.Type,or if none of the nested types match the 

    binding constraints.
  """
  pass
 def GetProperties(self,bindingAttr=None):
  """
  GetProperties(self: _Type) -> Array[PropertyInfo]

  

   Provides COM objects with version-independent access to the System.Type.GetProperties method.

   Returns: An array of System.Reflection.PropertyInfo objects representing all public properties of the 

    current System.Type.-or- An empty array of type System.Reflection.PropertyInfo,if the current 

    System.Type does not have public properties.

  

  GetProperties(self: _Type,bindingAttr: BindingFlags) -> Array[PropertyInfo]

  

   Provides COM objects with version-independent access to the 

    System.Type.GetProperties(System.Reflection.BindingFlags) method.

  

  

   bindingAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return null.

  

   Returns: An array of System.Reflection.PropertyInfo objects representing all properties of the current 

    System.Type that match the specified binding constraints.-or- An empty array of type 

    System.Reflection.PropertyInfo,if the current System.Type does not have properties,or if none 

    of the properties match the binding constraints.
  """
  pass
 def GetProperty(self,name,*__args):
  """
  GetProperty(self: _Type,name: str,types: Array[Type]) -> PropertyInfo

  

   Provides COM objects with version-independent access to the 

    System.Type.GetProperty(System.String,System.Type[]) method.

  

  

   name: The System.String containing the name of the public property to get.

   types: An array of System.Type objects representing the number,order,and type of the parameters for 

    the indexed property to get.-or- An empty array of the type System.Type (that is,Type[] types=

    new Type[0]) to get a property that is not indexed.

  

   Returns: A System.Reflection.PropertyInfo object representing the public property whose parameters match 

    the specified argument types,if found; otherwise,null.

  

  GetProperty(self: _Type,name: str,returnType: Type) -> PropertyInfo

  

   Provides COM objects with version-independent access to the 

    System.Type.GetProperty(System.String,System.Type) method.

  

  

   name: The System.String containing the name of the public property to get.

   returnType: The return type of the property.

   Returns: A System.Reflection.PropertyInfo object representing the public property with the specified 

    name,if found; otherwise,null.

  

  GetProperty(self: _Type,name: str) -> PropertyInfo

  

   Provides COM objects with version-independent access to the 

    System.Type.GetProperty(System.String) method.

  

  

   name: The System.String containing the name of the public property to get.

   Returns: A System.Reflection.PropertyInfo object representing the public property with the specified 

    name,if found; otherwise,null.

  

  GetProperty(self: _Type,name: str,returnType: Type,types: Array[Type]) -> PropertyInfo

  

   Provides COM objects with version-independent access to the 

    System.Type.GetProperty(System.String,System.Type,System.Type[]) method.

  

  

   name: The System.String containing the name of the public property to get.

   returnType: The return type of the property.

   types: An array of System.Type objects representing the number,order,and type of the parameters for 

    the indexed property to get.-or- An empty array of the type System.Type (that is,Type[] types=

    new Type[0]) to get a property that is not indexed.

  

   Returns: A System.Reflection.PropertyInfo object representing the public property whose parameters match 

    the specified argument types,if found; otherwise,null.

  

  GetProperty(self: _Type,name: str,bindingAttr: BindingFlags) -> PropertyInfo

  

   Provides COM objects with version-independent access to the 

    System.Type.GetProperty(System.String,System.Reflection.BindingFlags) method.

  

  

   name: The System.String containing the name of the property to get.

   bindingAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return null.

  

   Returns: A System.Reflection.PropertyInfo object representing the property that matches the specified 

    requirements,if found; otherwise,null.

  

  GetProperty(self: _Type,name: str,bindingAttr: BindingFlags,binder: Binder,returnType: Type,types: Array[Type],modifiers: Array[ParameterModifier]) -> PropertyInfo

  

   Provides COM objects with version-independent access to the 

    System.Type.GetProperty(System.String,System.Reflection.BindingFlags,System.Reflection.Binder,Sys

    tem.Type,System.Type[],System.Reflection.ParameterModifier[]) method.

  

  

   name: The System.String containing the name of the property to get.

   bindingAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted.-or- Zero,to return null.

  

   binder: A System.Reflection.Binder object that defines a set of properties and enables binding,which 

    can involve selection of an overloaded method,coercion of argument types,and invocation of a 

    member through reflection.-or- null,to use the System.Type.DefaultBinder.

  

   returnType: The return type of the property.

   types: An array of System.Type objects representing the number,order,and type of the parameters for 

    the indexed property to get.-or- An empty array of the type System.Type (that is,Type[] types=

    new Type[0]) to get a property that is not indexed.

  

   modifiers: An array of System.Reflection.ParameterModifier objects representing the attributes associated 

    with the corresponding element in the types array. The default binder does not process this 

    parameter.

  

   Returns: A System.Reflection.PropertyInfo object representing the property that matches the specified 

    requirements,if found; otherwise,null.

  

  GetProperty(self: _Type,name: str,returnType: Type,types: Array[Type],modifiers: Array[ParameterModifier]) -> PropertyInfo

  

   Provides COM objects with version-independent access to the 

    System.Type.GetProperty(System.String,System.Type,System.Type[],System.Reflection.ParameterModifi

    er[]) method.

  

  

   name: The System.String containing the name of the public property to get.

   returnType: The return type of the property.

   types: An array of System.Type objects representing the number,order,and type of the parameters for 

    the indexed property to get.-or- An empty array of the type System.Type (that is,Type[] types=

    new Type[0]) to get a property that is not indexed.

  

   modifiers: An array of System.Reflection.ParameterModifier objects representing the attributes associated 

    with the corresponding element in the types array. The default binder does not process this 

    parameter.

  

   Returns: A System.Reflection.PropertyInfo object representing the public property that matches the 

    specified requirements,if found; otherwise,null.
  """
  pass
 def GetType(self):
  """
  GetType(self: _Type) -> Type

  

   Provides COM objects with version-independent access to the System.Type.GetType method.

   Returns: The current System.Type.
  """
  pass
 def GetTypeInfo(self,iTInfo,lcid,ppTInfo):
  """
  GetTypeInfo(self: _Type,iTInfo: UInt32,lcid: UInt32,ppTInfo: IntPtr)

   Retrieves the type information for an object,which can then be used to get the type information 

    for an interface.

  

  

   iTInfo: The type information to return.

   lcid: The locale identifier for the type information.

   ppTInfo: Receives a pointer to the requested type information object.
  """
  pass
 def GetTypeInfoCount(self,pcTInfo):
  """
  GetTypeInfoCount(self: _Type) -> UInt32

  

   Retrieves the number of type information interfaces that an object provides (either 0 or 1).
  """
  pass
 def Invoke(self,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr):
  """
  Invoke(self: _Type,dispIdMember: UInt32,riid: Guid,lcid: UInt32,wFlags: Int16,pDispParams: IntPtr,pVarResult: IntPtr,pExcepInfo: IntPtr,puArgErr: IntPtr) -> Guid

  

   Provides access to properties and methods exposed by an object.

  

   dispIdMember: Identifies the member.

   riid: Reserved for future use. Must be IID_NULL.

   lcid: The locale context in which to interpret arguments.

   wFlags: Flags describing the context of the call.

   pDispParams: Pointer to a structure containing an array of arguments,an array of argument DISPIDs for named 

    arguments,and counts for the number of elements in the arrays.

  

   pVarResult: Pointer to the location where the result is to be stored.

   pExcepInfo: Pointer to a structure that contains exception information.

   puArgErr: The index of the first argument that has an error.
  """
  pass
 def InvokeMember(self,name,invokeAttr,binder,target,args,*__args):
  """
  InvokeMember(self: _Type,name: str,invokeAttr: BindingFlags,binder: Binder,target: object,args: Array[object]) -> object

  

   Provides COM objects with version-independent access to the 

    System.Type.InvokeMember(System.String,System.Reflection.BindingFlags,System.Reflection.Binder,Sy

    stem.Object,System.Object[]) method.

  

  

   name: The System.String containing the name of the constructor,method,property,or field member to 

    invoke.-or- An empty string ("") to invoke the default member. -or-For IDispatch members,a 

    string representing the DispID,for example "[DispID=3]".

  

   invokeAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted. The access can be one of the BindingFlags such as Public,NonPublic,Private,

    InvokeMethod,GetField,and so on. The type of lookup need not be specified. If the type of 

    lookup is omitted,BindingFlags.Public | BindingFlags.Instance will apply.

  

   binder: A System.Reflection.Binder object that defines a set of properties and enables binding,which 

    can involve selection of an overloaded method,coercion of argument types,and invocation of a 

    member through reflection.-or- null,to use the System.Type.DefaultBinder.

  

   target: The System.Object on which to invoke the specified member.

   args: An array containing the arguments to pass to the member to invoke.

   Returns: An System.Object representing the return value of the invoked member.

  InvokeMember(self: _Type,name: str,invokeAttr: BindingFlags,binder: Binder,target: object,args: Array[object],culture: CultureInfo) -> object

  

   Provides COM objects with version-independent access to the 

    System.Type.InvokeMember(System.String,System.Reflection.BindingFlags,System.Reflection.Binder,Sy

    stem.Object,System.Object[],System.Globalization.CultureInfo) method.

  

  

   name: The System.String containing the name of the constructor,method,property,or field member to 

    invoke.-or- An empty string ("") to invoke the default member. -or-For IDispatch members,a 

    string representing the DispID,for example "[DispID=3]".

  

   invokeAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted. The access can be one of the BindingFlags such as Public,NonPublic,Private,

    InvokeMethod,GetField,and so on. The type of lookup need not be specified. If the type of 

    lookup is omitted,BindingFlags.Public | BindingFlags.Instance will apply.

  

   binder: A System.Reflection.Binder object that defines a set of properties and enables binding,which 

    can involve selection of an overloaded method,coercion of argument types,and invocation of a 

    member through reflection.-or- null,to use the System.Type.DefaultBinder.

  

   target: The System.Object on which to invoke the specified member.

   args: An array containing the arguments to pass to the member to invoke.

   culture: The System.Globalization.CultureInfo object representing the globalization locale to use,which 

    may be necessary for locale-specific conversions,such as converting a numeric String to a 

    Double.-or- null to use the current thread's System.Globalization.CultureInfo.

  

   Returns: An System.Object representing the return value of the invoked member.

  InvokeMember(self: _Type,name: str,invokeAttr: BindingFlags,binder: Binder,target: object,args: Array[object],modifiers: Array[ParameterModifier],culture: CultureInfo,namedParameters: Array[str]) -> object

  

   Provides COM objects with version-independent access to the 

    System.Type.InvokeMember(System.String,System.Reflection.BindingFlags,System.Reflection.Binder,Sy

    stem.Object,System.Object[],System.Reflection.ParameterModifier[],System.Globalization.CultureInf

    o,System.String[]) method.

  

  

   name: The System.String containing the name of the constructor,method,property,or field member to 

    invoke.-or- An empty string ("") to invoke the default member. -or-For IDispatch members,a 

    string representing the DispID,for example "[DispID=3]".

  

   invokeAttr: A bitmask comprised of one or more System.Reflection.BindingFlags that specify how the search is 

    conducted. The access can be one of the BindingFlags such as Public,NonPublic,Private,

    InvokeMethod,GetField,and so on. The type of lookup need not be specified. If the type of 

    lookup is omitted,BindingFlags.Public | BindingFlags.Instance will apply.

  

   binder: A System.Reflection.Binder object that defines a set of properties and enables binding,which 

    can involve selection of an overloaded method,coercion of argument types,and invocation of a 

    member through reflection.-or- null,to use the System.Type.DefaultBinder.

  

   target: The System.Object on which to invoke the specified member.

   args: An array containing the arguments to pass to the member to invoke.

   modifiers: An array of System.Reflection.ParameterModifier objects representing the attributes associated 

    with the corresponding element in the args array. A parameter's associated attributes are stored 

    in the member's signature. The default binder does not process this parameter.

  

   culture: The System.Globalization.CultureInfo object representing the globalization locale to use,which 

    may be necessary for locale-specific conversions,such as converting a numeric String to a 

    Double.-or- null to use the current thread's System.Globalization.CultureInfo.

  

   namedParameters: An array containing the names of the parameters to which the values in the args array are passed.

   Returns: An System.Object representing the return value of the invoked member.
  """
  pass
 def IsAssignableFrom(self,c):
  """
  IsAssignableFrom(self: _Type,c: Type) -> bool

  

   Provides COM objects with version-independent access to the 

    System.Type.IsAssignableFrom(System.Type) method.

  

  

   c: The System.Type to compare with the current System.Type.

   Returns: true if c and the current System.Type represent the same type,or if the current System.Type is 

    in the inheritance hierarchy of c,or if the current System.Type is an interface that c 

    implements,or if c is a generic type parameter and the current System.Type represents one of 

    the constraints of c. false if none of these conditions are the case,or if c is null.
  """
  pass
 def IsDefined(self,attributeType,inherit):
  """
  IsDefined(self: _Type,attributeType: Type,inherit: bool) -> bool

  

   Provides COM objects with version-independent access to the 

    System.Reflection.MemberInfo.IsDefined(System.Type,System.Boolean) method.

  

  

   attributeType: The Type object to which the custom attributes are applied.

   inherit: Specifies whether to search this member's inheritance chain to find the attributes.

   Returns: true if one or more instance of attributeType is applied to this member; otherwise,false.
  """
  pass
 def IsInstanceOfType(self,o):
  """
  IsInstanceOfType(self: _Type,o: object) -> bool

  

   Provides COM objects with version-independent access to the 

    System.Type.IsInstanceOfType(System.Object) method.

  

  

   o: The object to compare with the current System.Type.

   Returns: true if the current System.Type is in the inheritance hierarchy of the object represented by o,

    or if the current System.Type is an interface that o supports. false if neither of these 

    conditions is the case,or if o is null,or if the current System.Type is an open generic type 

    (that is,System.Type.ContainsGenericParameters returns true).
  """
  pass
 def IsSubclassOf(self,c):
  """
  IsSubclassOf(self: _Type,c: Type) -> bool

  

   Provides COM objects with version-independent access to the 

    System.Type.IsSubclassOf(System.Type) method.

  

  

   c: The System.Type to compare with the current System.Type.

   Returns: true if the System.Type represented by the c parameter and the current System.Type represent 

    classes,and the class represented by the current System.Type derives from the class represented 

    by c; otherwise,false. This method also returns false if c and the current System.Type 

    represent the same class.
  """
  pass
 def ToString(self):
  """
  ToString(self: _Type) -> str

  

   Provides COM objects with version-independent access to the System.Type.ToString method.

   Returns: A System.String representing the name of the current System.Type.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __str__(self,*args):
  pass
 Assembly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.Assembly property.



Get: Assembly(self: _Type) -> Assembly



"""

 AssemblyQualifiedName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.AssemblyQualifiedName property.



Get: AssemblyQualifiedName(self: _Type) -> str



"""

 Attributes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.Attributes property.



Get: Attributes(self: _Type) -> TypeAttributes



"""

 BaseType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.BaseType property.



Get: BaseType(self: _Type) -> Type



"""

 DeclaringType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.DeclaringType property.



Get: DeclaringType(self: _Type) -> Type



"""

 FullName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.FullName property.



Get: FullName(self: _Type) -> str



"""

 GUID=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.GUID property.



Get: GUID(self: _Type) -> Guid



"""

 HasElementType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.HasElementType property.



Get: HasElementType(self: _Type) -> bool



"""

 IsAbstract=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsAbstract property.



Get: IsAbstract(self: _Type) -> bool



"""

 IsAnsiClass=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsAnsiClass property.



Get: IsAnsiClass(self: _Type) -> bool



"""

 IsArray=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsArray property.



Get: IsArray(self: _Type) -> bool



"""

 IsAutoClass=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsAutoClass property.



Get: IsAutoClass(self: _Type) -> bool



"""

 IsAutoLayout=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsAutoLayout property.



Get: IsAutoLayout(self: _Type) -> bool



"""

 IsByRef=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsByRef property.



Get: IsByRef(self: _Type) -> bool



"""

 IsClass=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsClass property.



Get: IsClass(self: _Type) -> bool



"""

 IsCOMObject=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsCOMObject property.



Get: IsCOMObject(self: _Type) -> bool



"""

 IsContextful=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsContextful property.



Get: IsContextful(self: _Type) -> bool



"""

 IsEnum=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsEnum property.



Get: IsEnum(self: _Type) -> bool



"""

 IsExplicitLayout=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsExplicitLayout property.



Get: IsExplicitLayout(self: _Type) -> bool



"""

 IsImport=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsImport property.



Get: IsImport(self: _Type) -> bool



"""

 IsInterface=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsInterface property.



Get: IsInterface(self: _Type) -> bool



"""

 IsLayoutSequential=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsLayoutSequential property.



Get: IsLayoutSequential(self: _Type) -> bool



"""

 IsMarshalByRef=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsMarshalByRef property.



Get: IsMarshalByRef(self: _Type) -> bool



"""

 IsNestedAssembly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsNestedAssembly property.



Get: IsNestedAssembly(self: _Type) -> bool



"""

 IsNestedFamANDAssem=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsNestedFamANDAssem property.



Get: IsNestedFamANDAssem(self: _Type) -> bool



"""

 IsNestedFamily=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsNestedFamily property.



Get: IsNestedFamily(self: _Type) -> bool



"""

 IsNestedFamORAssem=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsNestedFamORAssem property.



Get: IsNestedFamORAssem(self: _Type) -> bool



"""

 IsNestedPrivate=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsNestedPrivate property.



Get: IsNestedPrivate(self: _Type) -> bool



"""

 IsNestedPublic=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsNestedPublic property.



Get: IsNestedPublic(self: _Type) -> bool



"""

 IsNotPublic=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsNotPublic property.



Get: IsNotPublic(self: _Type) -> bool



"""

 IsPointer=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsPointer property.



Get: IsPointer(self: _Type) -> bool



"""

 IsPrimitive=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsPrimitive property.



Get: IsPrimitive(self: _Type) -> bool



"""

 IsPublic=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsPublic property.



Get: IsPublic(self: _Type) -> bool



"""

 IsSealed=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsSealed property.



Get: IsSealed(self: _Type) -> bool



"""

 IsSerializable=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsSerializable property.



Get: IsSerializable(self: _Type) -> bool



"""

 IsSpecialName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsSpecialName property.



Get: IsSpecialName(self: _Type) -> bool



"""

 IsUnicodeClass=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsUnicodeClass property.



Get: IsUnicodeClass(self: _Type) -> bool



"""

 IsValueType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.IsValueType property.



Get: IsValueType(self: _Type) -> bool



"""

 MemberType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.MemberType property.



Get: MemberType(self: _Type) -> MemberTypes



"""

 Module=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.Module property.



Get: Module(self: _Type) -> Module



"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.MemberInfo.Name property.



Get: Name(self: _Type) -> str



"""

 Namespace=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.Namespace property.



Get: Namespace(self: _Type) -> str



"""

 ReflectedType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.ReflectedType property.



Get: ReflectedType(self: _Type) -> Type



"""

 TypeHandle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.TypeHandle property.



Get: TypeHandle(self: _Type) -> RuntimeTypeHandle



"""

 TypeInitializer=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.TypeInitializer property.



Get: TypeInitializer(self: _Type) -> ConstructorInfo



"""

 UnderlyingSystemType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Type.UnderlyingSystemType property.



Get: UnderlyingSystemType(self: _Type) -> Type



"""





class GiveFeedbackEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.Control.GiveFeedback event,which occurs during a drag operation.

 

 GiveFeedbackEventArgs(effect: DragDropEffects,useDefaultCursors: bool)
 """
 @staticmethod
 def __new__(self,effect,useDefaultCursors):
  """ __new__(cls: type,effect: DragDropEffects,useDefaultCursors: bool) """
  pass
 Effect=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the drag-and-drop operation feedback that is displayed.



Get: Effect(self: GiveFeedbackEventArgs) -> DragDropEffects



"""

 UseDefaultCursors=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets whether drag operation should use the default cursors that are associated with drag-drop effects.



Get: UseDefaultCursors(self: GiveFeedbackEventArgs) -> bool



Set: UseDefaultCursors(self: GiveFeedbackEventArgs)=value

"""





class DataGridSortingEventArgs(DataGridColumnEventArgs):
 """
 Provides data for the System.Windows.Controls.DataGrid.Sorting event.

 

 DataGridSortingEventArgs(column: DataGridColumn)
 """
 @staticmethod
 def __new__(self,column):
  """ __new__(cls: type,column: DataGridColumn) """
  pass
 Handled=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that specifies whether the routed event is handled.



Get: Handled(self: DataGridSortingEventArgs) -> bool



Set: Handled(self: DataGridSortingEventArgs)=value

"""





class ObjectAccessRule(AccessRule):
 """ Represents a combination of a user's identity,an access mask,and an access control type (allow or deny). An System.Security.AccessControl.ObjectAccessRule object also contains information about the type of object to which the rule applies,the type of child object that can inherit the rule,how the rule is inherited by child objects,and how that inheritance is propagated. """
 @staticmethod
 def __new__(self,*args): #cannot find CLR constructor
  """ __new__(cls: type,identity: IdentityReference,accessMask: int,isInherited: bool,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags,objectType: Guid,inheritedObjectType: Guid,type: AccessControlType) """
  pass
 AccessMask=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the access mask for this rule.



"""

 InheritedObjectType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the type of child object that can inherit the stem.Security.AccessControl.ObjectAccessRule object.



Get: InheritedObjectType(self: ObjectAccessRule) -> Guid



"""

 ObjectFlags=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets flags that specify if the System.Security.AccessControl.ObjectAccessRule.ObjectType and System.Security.AccessControl.ObjectAccessRule.InheritedObjectType properties of the stem.Security.AccessControl.ObjectAccessRule object contain valid values.



Get: ObjectFlags(self: ObjectAccessRule) -> ObjectAceFlags



"""

 ObjectType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the type of object to which the stem.Security.AccessControl.ObjectAccessRule applies.



Get: ObjectType(self: ObjectAccessRule) -> Guid



"""





class DataGridViewComboBoxColumn(DataGridViewColumn,ICloneable,IDisposable,IComponent):
 """
 Represents a column of System.Windows.Forms.DataGridViewComboBoxCell objects.

 

 DataGridViewComboBoxColumn()
 """
 def Clone(self):
  """
  Clone(self: DataGridViewComboBoxColumn) -> object

  

   Creates an exact copy of this column.

   Returns: An System.Object that represents the cloned System.Windows.Forms.DataGridViewComboBoxColumn.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: DataGridViewColumn,disposing: bool)

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def OnDataGridViewChanged(self,*args):
  """
  OnDataGridViewChanged(self: DataGridViewBand)

   Called when the band is associated with a different System.Windows.Forms.DataGridView.
  """
  pass
 def RaiseCellClick(self,*args):
  """
  RaiseCellClick(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellClick event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseCellContentClick(self,*args):
  """
  RaiseCellContentClick(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellContentClick event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseCellContentDoubleClick(self,*args):
  """
  RaiseCellContentDoubleClick(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellContentDoubleClick event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseCellValueChanged(self,*args):
  """
  RaiseCellValueChanged(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellValueChanged event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseDataError(self,*args):
  """
  RaiseDataError(self: DataGridViewElement,e: DataGridViewDataErrorEventArgs)

   Raises the System.Windows.Forms.DataGridView.DataError event.

  

   e: A System.Windows.Forms.DataGridViewDataErrorEventArgs that contains the event data.
  """
  pass
 def RaiseMouseWheel(self,*args):
  """
  RaiseMouseWheel(self: DataGridViewElement,e: MouseEventArgs)

   Raises the System.Windows.Forms.Control.MouseWheel event.

  

   e: A System.Windows.Forms.MouseEventArgs that contains the event data.
  """
  pass
 def ToString(self):
  """
  ToString(self: DataGridViewComboBoxColumn) -> str

   Returns: A System.String that describes the column.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __str__(self,*args):
  pass
 AutoComplete=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether cells in the column will match the characters being entered in the cell with one from the possible selections.



Get: AutoComplete(self: DataGridViewComboBoxColumn) -> bool



Set: AutoComplete(self: DataGridViewComboBoxColumn)=value

"""

 CellTemplate=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the template used to create cells.



Get: CellTemplate(self: DataGridViewComboBoxColumn) -> DataGridViewCell



Set: CellTemplate(self: DataGridViewComboBoxColumn)=value

"""

 DataSource=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the data source that populates the selections for the combo boxes.



Get: DataSource(self: DataGridViewComboBoxColumn) -> object



Set: DataSource(self: DataGridViewComboBoxColumn)=value

"""

 DisplayMember=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a string that specifies the property or column from which to retrieve strings for display in the combo boxes.



Get: DisplayMember(self: DataGridViewComboBoxColumn) -> str



Set: DisplayMember(self: DataGridViewComboBoxColumn)=value

"""

 DisplayStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that determines how the combo box is displayed when not editing.



Get: DisplayStyle(self: DataGridViewComboBoxColumn) -> DataGridViewComboBoxDisplayStyle



Set: DisplayStyle(self: DataGridViewComboBoxColumn)=value

"""

 DisplayStyleForCurrentCellOnly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the System.Windows.Forms.DataGridViewComboBoxColumn.DisplayStyle property value applies only to the current cell in the System.Windows.Forms.DataGridView control when the current cell is in this column.



Get: DisplayStyleForCurrentCellOnly(self: DataGridViewComboBoxColumn) -> bool



Set: DisplayStyleForCurrentCellOnly(self: DataGridViewComboBoxColumn)=value

"""

 DropDownWidth=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the width of the drop-down lists of the combo boxes.



Get: DropDownWidth(self: DataGridViewComboBoxColumn) -> int



Set: DropDownWidth(self: DataGridViewComboBoxColumn)=value

"""

 FlatStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the flat style appearance of the column's cells.



Get: FlatStyle(self: DataGridViewComboBoxColumn) -> FlatStyle



Set: FlatStyle(self: DataGridViewComboBoxColumn)=value

"""

 HeaderCellCore=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the header cell of the System.Windows.Forms.DataGridViewBand.



"""

 IsRow=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the band represents a row.



"""

 Items=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of objects used as selections in the combo boxes.



Get: Items(self: DataGridViewComboBoxColumn) -> ObjectCollection



"""

 MaxDropDownItems=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the maximum number of items in the drop-down list of the cells in the column.



Get: MaxDropDownItems(self: DataGridViewComboBoxColumn) -> int



Set: MaxDropDownItems(self: DataGridViewComboBoxColumn)=value

"""

 Sorted=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the items in the combo box are sorted.



Get: Sorted(self: DataGridViewComboBoxColumn) -> bool



Set: Sorted(self: DataGridViewComboBoxColumn)=value

"""

 ValueMember=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a string that specifies the property or column from which to get values that correspond to the selections in the drop-down list.



Get: ValueMember(self: DataGridViewComboBoxColumn) -> str



Set: ValueMember(self: DataGridViewComboBoxColumn)=value

"""





"""
Element Model Wrappers provide a consitent interface for acccessing parameters and properties
of commonly used elements.

"""  #

import rpw
from rpw import revit, DB
from rpw.db.parameter import Parameter, ParameterSet
from rpw.base import BaseObjectWrapper
from rpw.exceptions import RpwException, RpwWrongStorageType
from rpw.exceptions import RpwParameterNotFound, RpwTypeError
from rpw.utils.logger import logger, deprecate_warning
from rpw.utils.mixins import CategoryMixin
from rpw.db.builtins import BicEnum, BipEnum
from rpw.utils.coerce import to_element_ids


class Element(BaseObjectWrapper, CategoryMixin):
    """
    Inheriting from element extends wrapped elements with a new :class:`parameters`
    attribute, well as the :func:`unwrap` method inherited from the :any:`BaseObjectWrapper` class.

    It can be created by instantiating ``rpw.db.Element`` , or one of the helper
    static methods shown below.

    Most importantly, all other `Element-related` classes inhert from this class
    so it can provide parameter access.

    >>> from rpw import db
    >>> element = db.Element(SomeElement)
    >>> element = db.Element.from_id(ElementId)
    >>> element = db.Element.from_int(Integer)

    >>> wall = db.Element(RevitWallElement)
    >>> wall.Id
    >>> wall.parameters['Height'].value
    10.0

    The ``Element`` Constructor can be used witout specifying the
    exact class. On instantiation, it will attempt to map the type provided,
    if a match is not found, an Element will be used.
    If the element does not inherit from DB.Element, and exception is raised.

    >>> wall_instance = db.Element(SomeWallInstance)
    >>> type(wall_instance)
    'rpw.db.WallInstance'
    >>> wall_symbol = db.Element(SomeWallSymbol)
    >>> type(wall_symbol)
    'rpw.db.WallSymbol'

    Attributes:

        parameters (:any:`ParameterSet`): Access :any:`ParameterSet` class.
        parameters.builtins (:any:`ParameterSet`): BuitIn :any:`ParameterSet` object

    Methods:
        unwrap(): Wrapped Revit Reference

    """

    _revit_object_class = DB.Element

    def __new__(cls, element, **kwargs):
        """
        Factory Constructor will chose the best Class for the Element.
        This function iterates through all classes in the rpw.db module,
        and will find one that wraps the corresponding class. If and exact
        match is not found :any:`Element` is used
        """
        defined_wrapper_classes = rpw.db.__all__

        _revit_object_class = cls._revit_object_class

        if element is None:
            raise RpwTypeError('Element or Element Child', 'None')

        # TODO: Handle double wrapping
        if hasattr(element, 'unwrap'):
            raise RpwTypeError('revit element', 'wrapped element: {}'.format(element))

        # Ensure Wrapped Element is instance of Class Wrapper or decendent
        if not isinstance(element, _revit_object_class):
            raise RpwTypeError(_revit_object_class.__name__,
                               element.__class__.__name__)

        # Ensure Wrapped Element is instance of Class Wrapper or decendent
        if not isinstance(element, _revit_object_class):
            raise RpwTypeError(_revit_object_class, element.__class__)

        # If explicit constructor was called, use that and skip discovery
        if type(element) is _revit_object_class:
            return super(Element, cls).__new__(cls, element, **kwargs)

        for wrapper_class in defined_wrapper_classes:
            class_name = wrapper_class.__name__
            if type(element) is getattr(wrapper_class, '_revit_object_class', None):
                # Found Mathing Class, Use Wrapper
                # print('Found Mathing Class, Use Wrapper: {}'.format(class_name))
                return super(Element, cls).__new__(wrapper_class, element, **kwargs)
        else:
            # Could Not find a Matching Class, Use Element if related
            return super(Element, cls).__new__(cls, element, **kwargs)

        # No early return. Should not reach this point
        element_class_name = element.__class__.__name__
        raise RpwException('Factory does not support type: {}'.format(element_class_name))

    def __init__(self, element, doc=None):
        """
        Main Element Instantiation

        >>> from rpw import db
        >>> wall = db.Element(SomeElementId)
        <rpw: WallInstance % DB.Wall >
        >>> wall.parameters['Height']
        10.0
        >>> wall.parameters.builtins['WALL_LOCATION_LINE']
        1

        Args:
            element (`Element Reference`): Can be ``DB.Element``, ``DB.ElementId``, or ``int``.

        Returns:
            :class:`Element`: Instance of Wrapped Element.

        """
        # rpw.ui.forms.Console(context=locals())
        super(Element, self).__init__(element)
        self.doc = element.Document if doc is None else revit.doc
        if isinstance(element, DB.Element):
            # WallKind Inherits from Family/Element, but is not Element,
            # so ParameterSet fails. Parameters are only added if Element
            # inherits from element
            # NOTE: This is no longer the case. Verify if it can be removed
            self.parameters = ParameterSet(element)

    @property
    def type(self):
        """
        Get's Element Type using the default GetTypeId() Method.
        For some Elements, this is the same as ``element.Symbol`` or ``wall.WallType``

        Args:
            doc (``DB.Document``, optional): Document of Element [default: revit.doc]

        Returns:
            (``Element``): Wrapped ``rpw.db.Element`` element type

        """
        element_type_id = self._revit_object.GetTypeId()
        element_type = self._revit_object.Document.GetElement(element_type_id)
        return Element(element_type)

    @property
    def name(self):
        """ Name Property """
        return DB.Element.Name.__get__(self.unwrap())

    @name.setter
    def name(self, value):
        """ Name Property Setter """
        return DB.Element.Name.__set__(self.unwrap(), value)

    @classmethod
    def collect(cls, **kwargs):
        """
        Collect all elements of the wrapper using the default collector.
        This method is defined on the main Element wrapper, but the
        collector parameters are defined in each wrapper. For example,
        :any:`WallType` uses the `_collector_params`:
        {'of_class': DB.WallType, 'is_type': True}

        These default collector parameters can be overriden by passing keyword
        args to the collectors call.

        >>> from rpw import db
        >>> wall_types_collector = db.WallType.collect()
        <rpw:Collector % FilteredElementCollector [count:4]>
        >>> wall_types_collector.get_elements()  # All Wall Types
        [<rpw:WallType [name:Wall 1] [id:1557]>, ... ]
        >>> wall_types_collector.get_elements()
        [<rpw:Area % DB.Area | Rentable:30.2>]
        >>> rooms = db.WallInstance.collect(level="Level 1")
        [<rpw:WallInstance % DB.Wall symbol:Basic Wall>]

        """
        _collector_params = getattr(cls, '_collector_params', None)

        if _collector_params:
            kwargs.update(_collector_params)
            return rpw.db.Collector(**kwargs)
        else:
            raise RpwException('Wrapper cannot collect by class: {}'.format(cls.__name__))

    @staticmethod
    def from_int(id_int, doc=None):
        """
        Instantiate Element from an Integer representing and Id

        Args:
            id (``int``): ElementId of Element to wrap
            doc (``DB.Document``, optional): Document of Element [default: revit.doc]

        Returns:
            (``Element``): Wrapped ``rpw.db.Element`` instance
        """
        doc = revit.doc if doc is None else doc
        element_id = DB.ElementId(id_int)
        return Element.from_id(element_id, doc=doc)

    @staticmethod
    def from_id(element_id, doc=None):
        """
        Instantiate Element from an ElementId

        Args:
            id (``ElementId``): ElementId of Element to wrap
            doc (``DB.Document``, optional): Document of Element [default: revit.doc]

        Returns:
            (``Element``): Wrapped ``rpw.db.Element`` instance

        """
        doc = doc or revit.doc
        element = doc.GetElement(element_id)
        return Element(element)

    @staticmethod
    def from_list(element_references, doc=None):
        """
        Instantiate Elements from a list of DB.Element instances

        Args:
            elements (``[DB.Element, DB.ElementId]``): List of element references

        Returns:
            (``list``): List of ``rpw.db.Element`` instances

        """
        doc = doc or revit.doc
        try:
            return [Element(e) for e in element_references]
        except RpwTypeError:
            pass
        try:
            element_ids = to_element_ids(element_references)
            return [Element.from_id(id_, doc=doc) for id_ in element_ids]
        except RpwTypeError:
            raise


    @staticmethod
    def Factory(element):
        deprecate_warning('Element.Factory()', replaced_by='Element()')
        return Element(element)

    def delete(self):
        """ Deletes Element from Model """
        self.doc.Delete(self._revit_object.Id)

    def __repr__(self, data=None):
        if data is None:
            data = {}
        element_id = getattr(self._revit_object, 'Id', None)
        if element_id:
            data.update({'id': element_id})
        return super(Element, self).__repr__(data=data)



class TraceEventCache(object):
 """
 Provides trace event data specific to a thread and a process.

 

 TraceEventCache()
 """
 Callstack=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the call stack for the current thread.



Get: Callstack(self: TraceEventCache) -> str



"""

 DateTime=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the date and time at which the event trace occurred.



Get: DateTime(self: TraceEventCache) -> DateTime



"""

 LogicalOperationStack=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the correlation data,contained in a stack.



Get: LogicalOperationStack(self: TraceEventCache) -> Stack



"""

 ProcessId=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the unique identifier of the current process.



Get: ProcessId(self: TraceEventCache) -> int



"""

 ThreadId=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a unique identifier for the current managed thread.



Get: ThreadId(self: TraceEventCache) -> str



"""

 Timestamp=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the current number of ticks in the timer mechanism.



Get: Timestamp(self: TraceEventCache) -> Int64



"""





# encoding: utf-8
# module System.Security.Authentication.ExtendedProtection.Configuration calls itself Configuration
# from System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class ExtendedProtectionPolicyElement(ConfigurationElement):
 """
 The System.Security.Authentication.ExtendedProtection.Configuration.ExtendedProtectionPolicyElement class represents a configuration element for an System.Security.Authentication.ExtendedProtection.ExtendedProtectionPolicy.

 

 ExtendedProtectionPolicyElement()
 """
 def BuildPolicy(self):
  """
  BuildPolicy(self: ExtendedProtectionPolicyElement) -> ExtendedProtectionPolicy

  

   The 

    System.Security.Authentication.ExtendedProtection.Configuration.ExtendedProtectionPolicyElement.B

    uildPolicy method builds a new 

    System.Security.Authentication.ExtendedProtection.ExtendedProtectionPolicy instance based on the 

    properties set on the 

    System.Security.Authentication.ExtendedProtection.Configuration.ExtendedProtectionPolicyElement 

    class.

  

   Returns: A new System.Security.Authentication.ExtendedProtection.ExtendedProtectionPolicy instance that 

    represents the extended protection policy created.
  """
  pass
 CustomServiceNames=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the custom Service Provider Name (SPN) list used to match against a client's SPN for this configuration policy element.



Get: CustomServiceNames(self: ExtendedProtectionPolicyElement) -> ServiceNameElementCollection



"""

 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 PolicyEnforcement=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the policy enforcement value for this configuration policy element.



Get: PolicyEnforcement(self: ExtendedProtectionPolicyElement) -> PolicyEnforcement



Set: PolicyEnforcement(self: ExtendedProtectionPolicyElement)=value

"""

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)

 ProtectionScenario=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the kind of protection enforced by the extended protection policy for this configuration policy element.



Get: ProtectionScenario(self: ExtendedProtectionPolicyElement) -> ProtectionScenario



Set: ProtectionScenario(self: ExtendedProtectionPolicyElement)=value

"""



class ServiceNameElement(ConfigurationElement):
 """
 The System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElement class represents a configuration element for a service name used in a System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElementCollection.

 

 ServiceNameElement()
 """
 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the Service Provider Name (SPN) for this System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElement instance.



Get: Name(self: ServiceNameElement) -> str



Set: Name(self: ServiceNameElement)=value

"""

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)



class ServiceNameElementCollection(ConfigurationElementCollection,ICollection,IEnumerable):
 """
 The System.Security.Authentication.ExtendedProtection.ServiceNameCollection class is a collection of service principal names that represent a configuration element for an System.Security.Authentication.ExtendedProtection.ExtendedProtectionPolicy.

 

 ServiceNameElementCollection()
 """
 def Add(self,element):
  """
  Add(self: ServiceNameElementCollection,element: ServiceNameElement)

   The 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElementCollection.Add(

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElement) method adds 

    a System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElement instance to 

    this 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElementCollection.

  

  

   element: The System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElement instance 

    to add to this 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElementCollection.
  """
  pass
 def BaseAdd(self,*args):
  """
  BaseAdd(self: ConfigurationElementCollection,index: int,element: ConfigurationElement)

   Adds a configuration element to the configuration element collection.

  

   index: The index location at which to add the specified System.Configuration.ConfigurationElement.

   element: The System.Configuration.ConfigurationElement to add.

  BaseAdd(self: ConfigurationElementCollection,element: ConfigurationElement,throwIfExists: bool)

   Adds a configuration element to the configuration element collection.

  

   element: The System.Configuration.ConfigurationElement to add.

   throwIfExists: true to throw an exception if the System.Configuration.ConfigurationElement specified is already 

    contained in the System.Configuration.ConfigurationElementCollection; otherwise,false.

  

  BaseAdd(self: ConfigurationElementCollection,element: ConfigurationElement)

   Adds a configuration element to the System.Configuration.ConfigurationElementCollection.

  

   element: The System.Configuration.ConfigurationElement to add.
  """
  pass
 def BaseClear(self,*args):
  """
  BaseClear(self: ConfigurationElementCollection)

   Removes all configuration element objects from the collection.
  """
  pass
 def BaseGet(self,*args):
  """
  BaseGet(self: ConfigurationElementCollection,index: int) -> ConfigurationElement

  

   Gets the configuration element at the specified index location.

  

   index: The index location of the System.Configuration.ConfigurationElement to return.

   Returns: The System.Configuration.ConfigurationElement at the specified index.

  BaseGet(self: ConfigurationElementCollection,key: object) -> ConfigurationElement

  

   Returns the configuration element with the specified key.

  

   key: The key of the element to return.

   Returns: The System.Configuration.ConfigurationElement with the specified key; otherwise,null.
  """
  pass
 def BaseGetAllKeys(self,*args):
  """
  BaseGetAllKeys(self: ConfigurationElementCollection) -> Array[object]

  

   Returns an array of the keys for all of the configuration elements contained in the 

    System.Configuration.ConfigurationElementCollection.

  

   Returns: An array that contains the keys for all of the System.Configuration.ConfigurationElement objects 

    contained in the System.Configuration.ConfigurationElementCollection.
  """
  pass
 def BaseGetKey(self,*args):
  """
  BaseGetKey(self: ConfigurationElementCollection,index: int) -> object

  

   Gets the key for the System.Configuration.ConfigurationElement at the specified index location.

  

   index: The index location for the System.Configuration.ConfigurationElement.

   Returns: The key for the specified System.Configuration.ConfigurationElement.
  """
  pass
 def BaseIndexOf(self,*args):
  """
  BaseIndexOf(self: ConfigurationElementCollection,element: ConfigurationElement) -> int

  

   The index of the specified System.Configuration.ConfigurationElement.

  

   element: The System.Configuration.ConfigurationElement for the specified index location.

   Returns: The index of the specified System.Configuration.ConfigurationElement; otherwise,-1.
  """
  pass
 def BaseIsRemoved(self,*args):
  """
  BaseIsRemoved(self: ConfigurationElementCollection,key: object) -> bool

  

   Gets a value indicating whether the System.Configuration.ConfigurationElement with the specified 

    key has been removed from the System.Configuration.ConfigurationElementCollection.

  

  

   key: The key of the element to check.

   Returns: true if the System.Configuration.ConfigurationElement with the specified key has been removed; 

    otherwise,false. The default is false.
  """
  pass
 def BaseRemove(self,*args):
  """
  BaseRemove(self: ConfigurationElementCollection,key: object)

   Removes a System.Configuration.ConfigurationElement from the collection.

  

   key: The key of the System.Configuration.ConfigurationElement to remove.
  """
  pass
 def BaseRemoveAt(self,*args):
  """
  BaseRemoveAt(self: ConfigurationElementCollection,index: int)

   Removes the System.Configuration.ConfigurationElement at the specified index location.

  

   index: The index location of the System.Configuration.ConfigurationElement to remove.
  """
  pass
 def Clear(self):
  """
  Clear(self: ServiceNameElementCollection)

   The 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElementCollection.Clea

    r method removes all configuration element objects from this 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElementCollection.
  """
  pass
 def CreateNewElement(self,*args):
  """
  CreateNewElement(self: ServiceNameElementCollection) -> ConfigurationElement

  CreateNewElement(self: ConfigurationElementCollection,elementName: str) -> ConfigurationElement

  

   Creates a new System.Configuration.ConfigurationElement when overridden in a derived class.

  

   elementName: The name of the System.Configuration.ConfigurationElement to create.

   Returns: A new System.Configuration.ConfigurationElement.
  """
  pass
 def DeserializeElement(self,*args):
  """
  DeserializeElement(self: ConfigurationElement,reader: XmlReader,serializeCollectionKey: bool)

   Reads XML from the configuration file.

  

   reader: The System.Xml.XmlReader that reads from the configuration file.

   serializeCollectionKey: true to serialize only the collection key properties; otherwise,false.
  """
  pass
 def GetElementKey(self,*args):
  """ GetElementKey(self: ServiceNameElementCollection,element: ConfigurationElement) -> object """
  pass
 def GetTransformedAssemblyString(self,*args):
  """
  GetTransformedAssemblyString(self: ConfigurationElement,assemblyName: str) -> str

  

   Returns the transformed version of the specified assembly name.

  

   assemblyName: The name of the assembly.

   Returns: The transformed version of the assembly name. If no transformer is available,the assemblyName 

    parameter value is returned unchanged. The 

    System.Configuration.Configuration.TypeStringTransformer property is null if no transformer is 

    available.
  """
  pass
 def GetTransformedTypeString(self,*args):
  """
  GetTransformedTypeString(self: ConfigurationElement,typeName: str) -> str

  

   Returns the transformed version of the specified type name.

  

   typeName: The name of the type.

   Returns: The transformed version of the specified type name. If no transformer is available,the typeName 

    parameter value is returned unchanged. The 

    System.Configuration.Configuration.TypeStringTransformer property is null if no transformer is 

    available.
  """
  pass
 def get_Item(self,*__args):
  """
  get_Item(self: ConfigurationElement,propertyName: str) -> object

  get_Item(self: ConfigurationElement,prop: ConfigurationProperty) -> object
  """
  pass
 def IndexOf(self,element):
  """
  IndexOf(self: ServiceNameElementCollection,element: ServiceNameElement) -> int

  

   The 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElementCollection.Inde

    xOf(System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElement) method 

    retrieves the index of the specified configuration element in this 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElementCollection.

  

  

   element: The System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElement instance 

    to retrieve the index of in this 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElementCollection.

  

   Returns: The index of the specified 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElement in this 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElementCollection.
  """
  pass
 def Init(self,*args):
  """
  Init(self: ConfigurationElement)

   Sets the System.Configuration.ConfigurationElement object to its initial state.
  """
  pass
 def InitializeDefault(self,*args):
  """
  InitializeDefault(self: ConfigurationElement)

   Used to initialize a default set of values for the System.Configuration.ConfigurationElement 

    object.
  """
  pass
 def IsElementName(self,*args):
  """
  IsElementName(self: ConfigurationElementCollection,elementName: str) -> bool

  

   Indicates whether the specified System.Configuration.ConfigurationElement exists in the 

    System.Configuration.ConfigurationElementCollection.

  

  

   elementName: The name of the element to verify.

   Returns: true if the element exists in the collection; otherwise,false. The default is false.
  """
  pass
 def IsElementRemovable(self,*args):
  """
  IsElementRemovable(self: ConfigurationElementCollection,element: ConfigurationElement) -> bool

  

   Gets a value indicating whether the specified System.Configuration.ConfigurationElement can be 

    removed from the System.Configuration.ConfigurationElementCollection.

  

  

   element: The element to check.

   Returns: true if the specified System.Configuration.ConfigurationElement can be removed from this 

    System.Configuration.ConfigurationElementCollection; otherwise,false. The default is true.
  """
  pass
 def IsModified(self,*args):
  """
  IsModified(self: ConfigurationElementCollection) -> bool

  

   Indicates whether this System.Configuration.ConfigurationElementCollection has been modified 

    since it was last saved or loaded when overridden in a derived class.

  

   Returns: true if any contained element has been modified; otherwise,false
  """
  pass
 def ListErrors(self,*args):
  """
  ListErrors(self: ConfigurationElement,errorList: IList)

   Adds the invalid-property errors in this System.Configuration.ConfigurationElement object,and 

    in all subelements,to the passed list.

  

  

   errorList: An object that implements the System.Collections.IList interface.
  """
  pass
 def OnDeserializeUnrecognizedAttribute(self,*args):
  """
  OnDeserializeUnrecognizedAttribute(self: ConfigurationElement,name: str,value: str) -> bool

  

   Gets a value indicating whether an unknown attribute is encountered during deserialization.

  

   name: The name of the unrecognized attribute.

   value: The value of the unrecognized attribute.

   Returns: true when an unknown attribute is encountered while deserializing; otherwise,false.
  """
  pass
 def OnDeserializeUnrecognizedElement(self,*args):
  """
  OnDeserializeUnrecognizedElement(self: ConfigurationElementCollection,elementName: str,reader: XmlReader) -> bool

  

   Causes the configuration system to throw an exception.

  

   elementName: The name of the unrecognized element.

   reader: An input stream that reads XML from the configuration file.

   Returns: true if the unrecognized element was deserialized successfully; otherwise,false. The default is 

    false.
  """
  pass
 def OnRequiredPropertyNotFound(self,*args):
  """
  OnRequiredPropertyNotFound(self: ConfigurationElement,name: str) -> object

  

   Throws an exception when a required property is not found.

  

   name: The name of the required attribute that was not found.

   Returns: None.
  """
  pass
 def PostDeserialize(self,*args):
  """
  PostDeserialize(self: ConfigurationElement)

   Called after deserialization.
  """
  pass
 def PreSerialize(self,*args):
  """
  PreSerialize(self: ConfigurationElement,writer: XmlWriter)

   Called before serialization.

  

   writer: The System.Xml.XmlWriter that will be used to serialize the 

    System.Configuration.ConfigurationElement.
  """
  pass
 def Remove(self,*__args):
  """
  Remove(self: ServiceNameElementCollection,name: str)

   The 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElementCollection.Remo

    ve(System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElement) method 

    removes a System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElement 

    instance from this 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElementCollection 

    based on the System.String specified.

  

  

   name: A System.String that represents the 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElement instance to 

    remove from this 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElementCollection

  

  Remove(self: ServiceNameElementCollection,element: ServiceNameElement)

   The 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElementCollection.Remo

    ve(System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElement) method 

    removes a System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElement 

    instance from this 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElementCollection.

  

  

   element: The System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElement instance 

    to remove from this 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElementCollection.
  """
  pass
 def RemoveAt(self,index):
  """
  RemoveAt(self: ServiceNameElementCollection,index: int)

   The 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElementCollection.Remo

    ve(System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElement) method 

    removes a System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElement 

    instance from this 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElementCollection 

    based on the index specified.

  

  

   index: The index of the 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElement instance to 

    remove from this 

    System.Security.Authentication.ExtendedProtection.Configuration.ServiceNameElementCollection.
  """
  pass
 def Reset(self,*args):
  """
  Reset(self: ConfigurationElementCollection,parentElement: ConfigurationElement)

   Resets the System.Configuration.ConfigurationElementCollection to its unmodified state when 

    overridden in a derived class.

  

  

   parentElement: The System.Configuration.ConfigurationElement representing the collection parent element,if 

    any; otherwise,null.
  """
  pass
 def ResetModified(self,*args):
  """
  ResetModified(self: ConfigurationElementCollection)

   Resets the value of the System.Configuration.ConfigurationElementCollection.IsModified property 

    to false when overridden in a derived class.
  """
  pass
 def SerializeElement(self,*args):
  """
  SerializeElement(self: ConfigurationElementCollection,writer: XmlWriter,serializeCollectionKey: bool) -> bool

  

   Writes the configuration data to an XML element in the configuration file when overridden in a 

    derived class.

  

  

   writer: Output stream that writes XML to the configuration file.

   serializeCollectionKey: true to serialize the collection key; otherwise,false.

   Returns: true if the System.Configuration.ConfigurationElementCollection was written to the configuration 

    file successfully.
  """
  pass
 def SerializeToXmlElement(self,*args):
  """
  SerializeToXmlElement(self: ConfigurationElement,writer: XmlWriter,elementName: str) -> bool

  

   Writes the outer tags of this configuration element to the configuration file when implemented 

    in a derived class.

  

  

   writer: The System.Xml.XmlWriter that writes to the configuration file.

   elementName: The name of the System.Configuration.ConfigurationElement to be written.

   Returns: true if writing was successful; otherwise,false.
  """
  pass
 def SetPropertyValue(self,*args):
  """
  SetPropertyValue(self: ConfigurationElement,prop: ConfigurationProperty,value: object,ignoreLocks: bool)

   Sets a property to the specified value.

  

   prop: The element property to set.

   value: The value to assign to the property.

   ignoreLocks: true if the locks on the property should be ignored; otherwise,false.
  """
  pass
 def SetReadOnly(self,*args):
  """
  SetReadOnly(self: ConfigurationElementCollection)

   Sets the System.Configuration.ConfigurationElementCollection.IsReadOnly property for the 

    System.Configuration.ConfigurationElementCollection object and for all sub-elements.
  """
  pass
 def set_Item(self,*__args):
  """ set_Item(self: ConfigurationElement,propertyName: str,value: object)set_Item(self: ConfigurationElement,prop: ConfigurationProperty,value: object) """
  pass
 def Unmerge(self,*args):
  """
  Unmerge(self: ConfigurationElementCollection,sourceElement: ConfigurationElement,parentElement: ConfigurationElement,saveMode: ConfigurationSaveMode)

   Reverses the effect of merging configuration information from different levels of the 

    configuration hierarchy

  

  

   sourceElement: A System.Configuration.ConfigurationElement object at the current level containing a merged view 

    of the properties.

  

   parentElement: The parent System.Configuration.ConfigurationElement object of the current element,or null if 

    this is the top level.

  

   saveMode: A System.Configuration.ConfigurationSaveMode enumerated value that determines which property 

    values to include.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y]x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]=x.__setitem__(i,y) <==> x[i]= """
  pass
 AddElementName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the System.Configuration.ConfigurationElement to associate with the add operation in the System.Configuration.ConfigurationElementCollection when overridden in a derived class.



"""

 ClearElementName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name for the System.Configuration.ConfigurationElement to associate with the clear operation in the System.Configuration.ConfigurationElementCollection when overridden in a derived class.



"""

 ElementName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name used to identify this collection of elements in the configuration file when overridden in a derived class.



"""

 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of properties.



"""

 RemoveElementName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the System.Configuration.ConfigurationElement to associate with the remove operation in the System.Configuration.ConfigurationElementCollection when overridden in a derived class.



"""

 ThrowOnDuplicate=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether an attempt to add a duplicate System.Configuration.ConfigurationElement to the System.Configuration.ConfigurationElementCollection will cause an exception to be thrown.



"""



